import React from "react";
import { connect } from "react-redux";
import { publicApi } from "../../redux/actions";
import { toast } from "react-toastify";
import "./index.css";

const CourseChapter = ({
  playList,
  seasons,
  book,
  grades,
  selectedVideo,
  userId,
  setVideoActive,
  isMobile,
}) => {
  const duration = (value) => {
    const minute = value % 60;
    const hour = Math.round(value / 60);
    return (
      (hour > 0
        ? (hour.toString().length === 1 ? "0" + hour.toString() : hour) + ""
        : "") +
      ":" +
      (minute.toString().length === 1 ? "0" + minute.toString() : minute)
    );
  };
  return (
    <section
      className={`bg-transparent lg:bg-green1 bg-opacity-10 lg:bg-opacity-10 lg:shadow-md lg:py-5 lg:pr-5 overflow-hidden flex flex-col rounded-md`}
      style={{
        minWidth: "calc(100% / 12 * 3.5)",
        height: isMobile ? "auto" : "calc(100vh - 300px)",
      }}
    >
      <div className="hidden lg:flex flex-row w-full items-center justify-between">
        <div>
          <h2 className="text-green7B bg-opacity-5 text-base font-semibold">
            {window.t("سرفصل دوره")}
          </h2>
        </div>
        <div className="flex flex-row-reverse items-center divide-x divide-solid transform translate-x-2">
          <span className="text-green7B text-sm px-2">{book?.name}</span>
          <span className="text-green7B text-sm px-2">
            {`${window.t("پایه")}` + " " + grades[book?.gradeId]}
          </span>
        </div>
      </div>
      <span className="hidden lg:flex w-full h-px bg-blue-200 my-4"></span>
      <div className="lg:overflow-y-scroll w-full hasScrollbar flex-1 flex flex-col">
        <div className="bg-green-600 rounded-sm p-4 flex flex-row items-center justify-between mb-2">
          <p className="text-tiny font-bold text-white">
            {seasons?.length > 0 &&
              playList?.length > 0 &&
              seasons?.filter((item) => item?.id === playList[0]?.categoryId)[0]
                ?.name}
          </p>
          {/* <span className="text-sm text-white">{video?.duration}</span> */}
        </div>
        {playList?.map((video, index) => (
          <div
            className={`flex flex-col lg:pl-4 ${
              video?.isFreeVod ? "cursor-pointer" : "cursor-not-allowed"
            }`}
            key={index}
          >
            <div
              className="flex flex-row items-center justify-around"
              key={index}
            >
              {/* right div dot dot */}
              <div
                className="hidden lg:flex items-center justify-center relative flex-col h-full"
                style={{ width: "10%" }}
              >
                <span
                  className={`w-px flex-1 transform -translate-x-0 ${
                    Number(index) !== 0 ? "border-dashed" : ""
                  } border-r border-blueC0`}
                ></span>
                <span className={`w-4 h-4 rounded-full bg-blueC0`}></span>
                <span
                  className={`w-px flex-1 transform -translate-x-0 ${
                    Number(index) !== playList?.length - 1
                      ? "border-dashed"
                      : ""
                  } border-r border-blueC0`}
                ></span>
              </div>
              {/* left div content  */}
              <div
                className="py-1.5"
                style={{ width: isMobile ? "100%" : "90%" }}
              >
                <div
                  className={`w-full bg-white flex flex-col transition duration-400  hover:scale-95 shadow-md border border-solid border-green-200 transform rounded-md
                  ${
                    selectedVideo?.id === video?.id
                      ? "bg-green-600 text-white"
                      : "text-blueC0 dark:bg-opacity-5"
                  }
                  `}
                  onClick={() =>
                    video?.isFreeVod || +userId === 140
                      ? setVideoActive(video)
                      : toast.error(window.t("ابتدا محصول رو خریداری کن!"))
                  }
                  disabled={true}
                >
                  {/* top */}
                  <div className="flex flex-row items-center justify-between p-3 border-0 border-b border-solid border-green-200">
                    <p
                      className={`text-base lg:text-tiny font-bold
                      ${selectedVideo?.id === video?.id ? "text-white" : ""}`}
                    >
                      {video?.name}
                    </p>
                    <span
                      className={`text-base lg:text-tiny  border-r border-solid border-blue-200 pr-1
                    ${
                      selectedVideo?.id === video?.id
                        ? "text-white"
                        : "text-blueC0"
                    }`}
                    >
                      {duration(video?.duration)}
                    </span>
                  </div>
                  {/* divider */}
                  <div
                    className={`border-t border-blue-600 ${
                      selectedVideo?.id === video?.id ? "border-red-600" : ""
                    }`}
                  ></div>
                  {/* bottom */}
                  <span
                    className={`text-base lg:text-tiny text-center font-bold p-3
                  ${
                    selectedVideo?.id === video?.id
                      ? "text-white"
                      : "text-blueC0"
                  }`}
                  >
                    {selectedVideo?.id === video?.id
                      ? `${window.t("در حال پخش")}`
                      : `${window.t("پخش")}`}
                  </span>
                </div>
              </div>
            </div>
          </div>
        ))}
      </div>
    </section>
  );
};

const mapStateToProps = (state) => ({
  selectedVideo: state.publicApi.selectedVideo,
  seasons: state.publicApi.bookInfo?.categories,
  book: state.publicApi.bookInfo,
  grades: state.publicApi.grades,
  // vods: state.publicApi.bookSection?.vods,
  userId: state?.user?.status?.id,
  isMobile: state.publicApi.isMobile,
});

const mapDispatchToProps = {
  setVideoActive: publicApi.setVideoActive,
};

export default connect(mapStateToProps)(CourseChapter);
