import React, { useState } from "react";
import _ from "lodash";
import "./index.scss";

const langDetector = (lang, option1, option2) => {
  return lang === "fa" ? option1 : option2;
};

const inputStatusHandler = (value, focus, status, primary, success, danger) => {
  if (!focus) {
    return "";
  } else {
    if (!value) {
      return primary;
    } else {
      if (status) {
        return success;
      } else {
        return;
      }
    }
  }
};

export default function Input(props) {
  const [focusToggle, setFocusToggle] = useState(false);

  const {
    backgroundColor,
    lang,
    theme,
    inputMode,
    label,
    status,
    maxLength,
    message,
    onChange,
    align,
    name,
    regex,
    direction,
    width,
    value,
  } = props;

  return (
    <div
      className={_.join(
        [
          "input flex flex-col relative my-2 dark:bg-opacity-10  w-full",
          langDetector(lang, "fa", "en"),
        ],
        " "
      )}
      style={{ width }}
    >
      {/* <label
        className={_.join(
          [
            "absolute top-1/2 transform -translate-y-1/2 text-gray-500 dark:text-white  px-2 text-xs transition-all duration-300",
            langDetector(lang, "right-2", "left-2"),
            inputStatusHandler(
              value,
              focusToggle,
              status,
              "input__labelFocus",
              "input__labelSuccess",
              "input__labelDanger"
            ),
          ],
          " "
        )}
        onClick={() => setFocusToggle(true)}
      >
        {label}
      </label> */}
      <input
        type="text"
        inputMode={inputMode}
        placeholder={label}
        className={_.join(
          [
            `flex-1 border border-gray-300 dark:bg-opacity-10 dark:text-white  rounded-md outline-none py-3 px-4 text-tiny ${
              backgroundColor ? backgroundColor : "bg-transparent"
            } ${align}`,
            inputStatusHandler(
              value,
              focusToggle,
              status,
              "input__inputActive",
              "input__inputSuccess",
              "input__inputDanger"
            ),
            "transition",
          ],
          " "
        )}
        value={value}
        style={{ direction: direction }}
        onChange={(e) =>
          onChange(name, (e.target.value = regex(e.target.value)))
        }
        onFocus={() => setFocusToggle(true)}
        onBlur={() => (!value ? setFocusToggle(false) : setFocusToggle(true))}
        maxLength={maxLength}
      />
      {/* {!status && value && (
        <img
          src={danger}
          alt={langDetector(lang, "اشتباه", "wrong")}
          className={_.join(
            [
              "w-4 h-4 absolute top-1/2 transform -translate-y-1/2",
              langDetector(lang, "left-2", "right-2"),
            ],
            " "
          )}
        />
      )} */}
      {/* {status && value && (
        <img
          src={tick}
          alt={langDetector(lang, "درست", "right")}
          className={_.join(
            [
              "w-4 h-4 absolute top-1/2 transform -translate-y-1/2",
              langDetector(lang, "left-2", "right-2"),
            ],
            " "
          )}
        />
      )} */}

      {value && !status && (
        <span
          className={_.join(
            [
              "input__message text-xs absolute -bottom-5",
              langDetector(lang, "right-2", "left-2"),
              inputStatusHandler(
                value,
                focusToggle,
                status,
                "",
                "input__messageSuccess",
                "input__messageDanger"
              ),
              "transition",
            ],
            " "
          )}
        >
          {message}
        </span>
      )}
      {/* {value && (
        <span
          className={_.join(
            [
              "input__length absolute -bottom-5 text-xs",
              langDetector(lang, "left-2", "right-2"),
              inputStatusHandler(
                value,
                focusToggle,
                status,
                "",
                "input__lengthSuccess",
                "input__lengthDanger"
              ),
              "transition",
            ],
            " "
          )}
        >
          {value.length + "/" + maxLength}
        </span>
      )} */}
    </div>
  );
}

Input.defaultProps = {
  lang: "fa",
  inputMode: "numeric",
  label: "label",
  status: "",
  maxLength: "",
  message: "",
  direction: "rtl",
};
