import React, { useEffect, useState } from "react";
import { connect } from "react-redux";
import { Link } from "react-router-dom";

const Pages = [
  {
    strings: "خانه - home - Home - Landing - landing",
    link: "/",
    name: window.t("خانه"),
  },
  {
    strings: "ورود - ثبت نام - لاگین - login - Login",
    link: "/signup",
    name: window.t("ورود یا ثبت نام"),
  },
  {
    strings:
      "کتاب - محصول - ویدئو - book - video - books - videos - خرید - ریاضی - علوم - شیمی - زیست - محصولات - ویدئوها - کتاب‌ها",
    link: "/products",
    name: window.t("محصولات"),
  },
  {
    strings:
      "آدرس - شماره تماس - ارتباط با ما - نقشه - تیکت - شکایت - address - map - phone number - contact us",
    link: "/contact-us",
    name: window.t("ارتباط با ما"),
  },
];

export const SearchResult = ({ text, books, setText }) => {
  const [relatedBooks, setRelatedBooks] = useState([]);
  const [relatedPages, setRelatedPages] = useState([]);

  useEffect(() => {
    if (text && books.length > 0) {
      let list = books.filter(
        (book) =>
          book.product[0].name.indexOf(text) !== -1 ||
          book.product[1].name.indexOf(text) !== -1
      );
      let pages = Pages.filter((page) => page.strings.indexOf(text) !== -1);
      setRelatedPages(pages);
      setRelatedBooks(list);
    }
  }, [text]);

  return (
    <div className="w-full list-none relative z-50">
      <div
        onClick={(e) => e.stopPropagation()}
        className="absolute -top-1 w-full left-0 px-6 pt-5 bg-white pb-5 shadow-lg rounded-md flex flex-col overflow-y-scroll z-50"
        style={{ maxHeight: "calc(100vh / 1.5)", direction: "ltr" }}
      >
        <header className="w-full flex flex-row-reverse items-center gap-4">
          <strong className="text-greenBA font-normal text-sm">
            {window.t("محصولات")}
          </strong>
          <span
            className="flex-1 bg-greenBA bg-opacity-30"
            style={{ height: 1 }}
          ></span>
        </header>
        {relatedBooks.length > 0 ? (
          <ul className="list-none p-0 m-0 mt-4 flex flex-col gap-3 divide-solid divide-y divide-gray-200">
            {relatedBooks.map((book, index) => (
              <Link
                to={"/products/" + book.id}
                className="flex flex-row-reverse w-full gap-4 items-center"
                ley={index}
                onClick={() => setText(null)}
              >
                <img
                  style={{
                    height: "calc(100vh / 17)",
                    width: "calc(100vh / 17 * 2 / 3)",
                  }}
                  className="rounded-sm"
                  src={`https://dnvn.ir/api/v1/file/${book.fileIds}`}
                  alt=""
                ></img>
                <strong className="text-sm pt-2 text-blueC0 font-semibold">
                  {book.product[1].name}
                </strong>
              </Link>
            ))}
          </ul>
        ) : (
          <span
            style={{ direction: "rtl" }}
            className="text-blueC0 text-sm text-right py-4 font-semibold"
          >
            {window.t("هیچ محصولی یافت نشد.")}
          </span>
        )}
        <header className="w-full flex flex-row-reverse items-center gap-4 mt-5">
          <strong className="text-greenBA font-normal text-sm">
            {window.t("صفحات")}
          </strong>
          <span
            className="flex-1 bg-greenBA bg-opacity-30"
            style={{ height: 1 }}
          ></span>
        </header>
        {relatedPages.length > 0 ? (
          <ul className="list-none p-0 m-0 mt-4 flex flex-col gap-3 divide-solid divide-y divide-gray-200">
            {relatedPages.map((page, index) => (
              <Link
                to={page.link}
                className="flex flex-row-reverse w-full gap-4 items-center text-green-800 text-tiny font-semibold underline"
                ley={index}
                onClick={() => setText(null)}
              >
                {page.name}
              </Link>
            ))}
          </ul>
        ) : (
          <span
            style={{ direction: "rtl" }}
            className="text-blueC0 text-sm text-right py-4 font-semibold"
          >
            {window.t("هیچ صفحه ای موجود نیست")}
          </span>
        )}
      </div>
    </div>
  );
};

const mapStateToProps = (state) => ({
  books: state.book.list,
});

const mapDispatchToProps = {};

export default connect(mapStateToProps, mapDispatchToProps)(SearchResult);
