import React from "react";
import { connect } from "react-redux";
import { userProduct } from "../../redux/actions";
import { toast } from "react-toastify";
import separate from "../../utils/separate";
//components;
import Button from "../Button";
import location from "../../utils/location";

//assets
import arrow from "./arrow-icon.svg";
import delivery from "./delivery-icon.svg";
import circle from "./info-circle.svg";
import shield from "./shield-tick.svg";
import tick from "./tick-circle.svg";
import shop from "./icon-shop.svg";
import bookmarkDeactiveLightIcon from "../../assets/icons/bookmark-deactive-light.svg";
import bookmarkDeactiveDarkIcon from "../../assets/icons/bookmark-deactive-dark.svg";

const ProductStatusCard = ({
  price,
  offerPrice,
  isDark,
  id,
  userId,
  isLogin,
  pushToCart,
  loading,
  garanty,
  suggestedCounter,
  seller,
  shippingTime,
  addToFavorite,
  headerOptions,
}) => {
  const { bookmark } = headerOptions;
  return (
    <section className="w-full" style={{ minWidth: 350 }}>
      <div className="bg-grayF9 rounded-md px-4 py-2 divide-y divide-solid divide-gray-200">
        <div className="flex flex-row items-center justify-between py-3">
          <div className="flex flex-row items-center">
            <img src={tick} alt="" className="w-8" />
            <div className="flex flex-col mr-3">
              <div className="text-sm">{`${window.t(
                "توصیه به خرید توسط"
              )}  ${suggestedCounter} ${window.t("نفر")} `}</div>
            </div>
          </div>
        </div>

        {seller && (
          <div className="flex flex-row items-center justify-between py-3">
            <div className="flex flex-row items-center">
              <img src={shop} alt="" className="w-8" />
              <div className="flex flex-1 flex-col mr-3 text-sm gap-2">
                <div className="text-tiny">{"فروشنده" + " " + seller.name}</div>
                <div className="text-xs">
                  {`${window.t("پایه")}` + " " + "%" + seller.rate * 20}
                </div>
              </div>
            </div>
            <img src={circle} alt="" className="w-5" />
          </div>
        )}

        <div className="flex flex-row items-center justify-between py-3">
          <div className="flex flex-row items-center">
            <img src={delivery} alt="" className="w-8" />
            <div className="flex flex-col mr-3">
              <div className="flex flex-row gap-1 text-sm">
                &nbsp;{shippingTime}
              </div>
            </div>
          </div>
        </div>

        {garanty && (
          <div className="flex flex-row items-center justify-between py-3">
            <div className="flex flex-row items-center">
              <img src={shield} alt="" className="w-8" />
              <div className="flex flex-col mr-3">
                <div className="flex flex-row gap-1 text-sm">{garanty}</div>
              </div>
            </div>
          </div>
        )}

        {bookmark && (
          <div className="flex flex-row items-center py-3">
            <img
              src={
                isDark ? bookmarkDeactiveDarkIcon : bookmarkDeactiveLightIcon
              }
              alt="bookmark"
              className="w-7"
              onClick={() => addToFavorite({ [bookmark]: location.getId() })}
            />
            <span className="mr-3 text-sm">
              اضافه کردن به لیست علاقه مندی ها
            </span>
          </div>
        )}

        <div className="flex flex-col items-center py-3">
          <p className="text-6xl text-blueC0 font-bold ">
            {separate(price)}
            <span className="text-sm text-gray-700 font-light mr-1">
              {window.t("تومان")}
            </span>
          </p>
          {offerPrice && (
            <p className="text-xs font-light text-gray-600 mt-2">
              {window.t("با خرید این کالا")}
              <span className="text-sm font-bold">
                {" " +
                  separate(price - offerPrice) +
                  " " +
                  "${`window.t(تومان)`}"}
              </span>
              {window.t("صرفه جویی کنید")}
            </p>
          )}
        </div>

        <Button
          title={window.t("اضافه کردن به سبد خرید")}
          backgroundColor={isDark ? "bg-blueC0" : "bg-blueC0"}
          border={{ color: isDark ? "#ffffff55" : "#196EC055", width: "0px" }}
          width="100%"
          color={"text-white"}
          selectable={true}
          loading={loading}
          onClick={() =>
            isLogin
              ? pushToCart({
                  productId: id,
                  userId: userId,
                  count: 1,
                })
              : toast.info(window.t("ابتدا وارد حساب کاربری خود شوید."))
          }
        />
      </div>
      <div className="bg-grayF9 rounded px-4 py-2 mt-4 flex flex-row items-center">
        <div>
          <img src={arrow} alt="" className="w-20 h-20" />
        </div>
        <div className="flex flex-col mr-5">
          <h2 className="text-sm font-bold text-green-900">
            {window.t("بازگشت بی چون و چرا")}
          </h2>
          <p className="text-xs mt-2 leading-5 text-justify">
            {window.t(
              "از اونجایی که ما خیلی خوب هستیم و دوستون داریم در صورتی که از کالایی خوشتون نیومده میتونید بی قید و شرط پس بدید"
            )}
          </p>
        </div>
      </div>
    </section>
  );
};

const mapStateToProps = (state) => ({
  isDark: state.publicApi.isDark,
  isLogin: state.user.status,
  userId: state.user.status.id,
  headerOptions: state.publicApi.headerOptions,
});

const mapDispatchToProps = {
  pushToCart: userProduct.add,
};

export default connect(mapStateToProps, mapDispatchToProps)(ProductStatusCard);
