import React, { useState } from "react";
import Table from "./table";

const ProductTab = ({ tabs }) => {
  const [selectedTab, setSelectedTab] = useState(tabs[0]);

  return (
    <section className="mt-10 flex flex-col w-full">
      <div className="rounded-md bg-grayF9">
        <ul className="flex flex-row justify-center gap-16">
          {tabs.map((tab, index) =>
            tab.shown ? (
              <li
                className={`text-tiny font-semibold cursor-pointer hover:text-blueC0 py-4 transition-all duration-500 ${
                  selectedTab?.title === tab?.title
                    ? "text-blueC0 border-b-4 border-solid border-blueC0"
                    : "border-b-4 border-solid border-transparent"
                }`}
                onClick={() => setSelectedTab(tab)}
                key={index}
              >
                {tab.title}
              </li>
            ) : (
              <></>
            )
          )}
        </ul>
      </div>
      <div className={`rounded w-full flex items-center`}>
        {selectedTab?.components}
      </div>
    </section>
  );
};

export default ProductTab;

ProductTab.defaultProps = {
  tabs: [
    {
      title: window.t("مشخصات"),
      components: <Table />,
    },
    {
      title: window.t("پرسش"),
      components: (
        <div className="bg-gray-100 rounded-md mt-4 w-full flex justify-center items-center h-40 text-green4F text-tiny">
          {window.t("این بخش فعلا قابل دسترسی نیست. بی چون و چرا")}
        </div>
      ),
    },
    {
      title: window.t("سوال"),
      components: (
        <div className="bg-gray-100 rounded-md mt-4 w-full flex justify-center items-center h-40 text-green4F text-tiny">
          {window.t("این بخش فعلا قابل دسترسی نیست.")}
        </div>
      ),
    },
  ],
};
