import React from "react";
import { connect } from "react-redux";
import { publicApi } from "../../redux/actions";
import _ from "lodash";

//assets
import searchIcon from "./search.png";

const langDetector = (lang = "fa", option1, option2) => {
  return lang === "fa" ? option1 : option2;
};

function Search(props) {
  return (
    <div className="flex items-center justify-center w-full my-3 bg-white z-50 overflow-hidden rounded-md">
      <div className="relative text-gray-600 focus-within:text-gray-400 w-full">
        <span
          className={_.join(
            [
              "absolute inset-y-0 flex items-center pl-2",
              langDetector(props.lang, "left-0", "right-0"),
            ],
            " "
          )}
        >
          <button
            type="submit"
            className="p-1 focus:outline-none focus:shadow-outline"
          >
            <img src={searchIcon} className="w-6 h-6" alt="" />
          </button>
        </span>
        <input
          type="search"
          name={props.name}
          className={`z-50 w-full py-3 text-base lg:text-tiny lg:font-semibold ${
            props.backgroundColor
          } ${
            props.textColor ? props.textColor : "text-gray1"
          } border border-solid border-gray-200 rounded-md pr-5 pl-14 outline-none focus:ring-1 focus:text-gray-900 `}
          placeholder={_.join(
            [langDetector(props.lang, "جستجو...", "Search...")],
            " "
          )}
          autoComplete="off"
          onChange={(e) => props.onChange(e.target.value)}
          onFocus={() => props.setOverLayer(true)}
          onBlur={() => props.setOverLayer(false)}
        />
      </div>
    </div>
  );
}

const mapStateToProps = (state) => ({});

const mapDispatchToProps = {
  setOverLayer: publicApi.setOverLayer,
};

export default connect(mapStateToProps, mapDispatchToProps)(Search);
