import React, { useState } from "react";
import searchIcon from "./search.png";
import _ from "lodash";
import Checkbox from "../Checkbox";
import arrowIcon from "./arrow-top.png";

const langDetector = (lang = "fa", option1, option2) => {
  return lang === "fa" ? option1 : option2;
};

export default function VerticalExpandableProductFilter(props) {
  const [searchResult, setSearchResult] = useState([]);
  const [checkedBox, setChecked] = useState([]);
  const name = props.name || Math.random();

  return (
    <div className="flex flex-col w-full border border-solid border-gray-100 rounded-md pt-6 bg-transparent max-h-screen bg-white my-3">
      <strong className="text-tiny text-greenBA w-full mb-3 text-right px-3">
        {props.title}
      </strong>
      {props.searchAble && (
        <form className="relative w-full px-3 mb-3">
          <input
            type="text"
            placeholder={_.join(
              [langDetector(props.lang, "جستجو...", "Search...")],
              " "
            )}
            className="border rounded-md py-1 px-2 w-full placeholder-gray-300 outline-none text-gray-500"
            onChange={(e) => setText(e.target.value)}
          />
          <span
            className={_.join(
              [
                "absolute inset-y-0 flex items-center",
                langDetector(props.lang, "left-4", "right-4"),
              ],
              " "
            )}
          >
            <button
              type="submit"
              className="p-1 focus:outline-none focus:shadow-outline"
            >
              <img src={searchIcon} className="w-5 h-5" alt="" />
            </button>
          </span>
        </form>
      )}
      <ul
        className="w-full list-none flex flex-col divide-y divide-gray-100 overflow-y-scroll"
        style={{ maxHeight: "calc(100vh / 3.5)", minHeight: 200 }}
      >
        {(searchResult.length > 0 ? searchResult : props.list)?.map(
          (item1, i) => (
            <li
              key={i}
              className="hover:bg-gray-100 px-3 flex flex-row items-center justify-between py-2"
            >
              <div className="flex flex-row items-center">
                <Checkbox
                  name={`ch${name}_${i}`}
                  checked={true}
                  onclick={(e) => {
                    checkedBox[i] = !checkedBox[i];
                    setChecked(checkedBox);
                  }}
                  onChange={() => props.onChange(name, item1.name)}
                />
                <strong className=" text-greenBA text-sm rounded py-1 px-0 font-light">
                  {props.preName ? props.preName + " " + item1.name : item1}
                </strong>
              </div>

              {item1?.subList?.length > 0 && (
                <img
                  src={arrowIcon}
                  alt=""
                  className={_.join(
                    [
                      "cursor-pointer w-5 transform transition-all duration-300",
                      item1.expaneded ? "" : "rotate-180",
                    ],
                    " "
                  )}
                />
              )}
            </li>
          )
        )}
      </ul>
      {props.btnTitle && (
        <div className="flex align-center justify-center">
          <button
            className="my-4 bg-blueFFOP text-sm bg-opacity-40 transition-all w-4/5 py-3 px-6 rounded text-blueC0 hover:text-white hover:bg-blueC0"
            onClick={props.btnClicked}
          >
            {props.btnTitle}
          </button>
        </div>
      )}
    </div>
  );
}
