import { toast } from "react-toastify";
import filter from "../../utils/filter";

const initialState = {
  loading: false,
  error: null,
  list: [],
  info: null,
  searchResult: [],
  filterResult: [],
  subjects: [],
  levels: [],
  sortFilters: ["محبوب ترین", "جدیدترین", "ارزان ترین"],
  selectedVideo: null,
  gradeFilterBooks: null,
  sortFilterCourse: null,
  selectedGrade: null,
  selectedSort: "پربازدید ترین ها",
  productTypes:
    window.innerWidth >= 1024
      ? ["کتاب فیزیکی", "کتاب دیجیتال", "دوره ویدئویی", "بسته های آموزشی"]
      : [
          "نوع محصول",
          "کتاب فیزیکی",
          "کتاب دیجیتال",
          "دوره ویدئویی",
          "بسته های آموزشی",
        ],
  filterOptions: {
    grade: "",
    subject: "",
    productType: null,
    available: false,
    sort: null,
    search: "",
  },
};

const grades = [
  "پیش دبستان",
  "اول",
  "دوم",
  "سوم",
  "چهارم",
  "پنجم",
  "ششم",
  "هفتم",
  "هشتم",
  "نهم",
  "دهم",
  "یازدهم",
  "دوازدهم",
];

export default function book(state = initialState, action) {
  let { type, data } = action;
  switch (type) {
    case "book/list":
      let itemsSubject = (Array.isArray(data) ? data : []).map(
        (item, index) => item.name
      );
      if (window.innerWidth < 1000) {
        itemsSubject.unshift("نام کتاب");
      }
      let itemsLevel = (Array.isArray(data) ? data : [])
        .map((item) => item.gradeId * 1)
        .sort((a, b) => a - b)
        .map((e) => grades[e]);
      if (window.innerWidth < 1000) {
        itemsLevel.unshift("پایه تحصیلی");
      }
      return {
        ...state,
        loading: false,
        list: data,
        subjects: Array.from(new Set(itemsSubject)),
        levels: Array.from(new Set(itemsLevel)),
        filterResult: data,
        error: null,
      };
    case "book/info":
      return { ...state, loading: false, info: data, error: null };
    case "book/lesson/active":
      return {
        ...state,
        loading: false,
        error: null,
      };
    case "book/gradeFilter":
      if (data === state.selectedGrade) {
        return { ...state, gradeFilterBooks: null, selectedGrade: null };
      } else {
        return {
          ...state,
          gradeFilterBooks: state.list.filter(
            (item, i) => grades[item.gradeId] === data
          ),
          selectedGrade: data,
        };
      }
    case "book/sortFilter":
      const search = state.list.filter(
        (item) => item.name.indexOf(data.search) !== -1
      );
      if (data.sort === "تمامی دوره‌ها") {
        return { ...state, sortFilterCourse: search, selectedSort: data.sort };
      } else if (data.sort === "جدیدترین‌ها") {
        return {
          ...state,
          sortFilterCourse: search.sort((item1, item2) => {
            return item1.publishYear - item2.publishYear;
          }),
          selectedSort: data.sort,
        };
      }
      return { ...state, sortFilterCourse: search, selectedSort: data.sort };

    // case "book/update":
    //   return { ...state, loading: false, error: null };
    // case "book/add":
    //   return { ...state, loading: false, error: null };
    // case "book/delete":
    //   return { ...state, loading: false, error: null };
    // case "book/search":
    //   return { ...state };
    case "book/setFilterOptions":
      return { ...state, loading: false, error: null, filterOptions: data };
    case "book/loading":
      return { ...state, loading: true };
    case "book/error":
      toast.error(data.message);
      return { ...state, loading: false, error: data.message };
    default:
      return state;
  }
}
