import React, { useEffect } from "react";
import { connect } from "react-redux";
import { publicApi } from "../../redux/actions";
import Header from "./components/Header";
import OR from "../../components/OR";
import Button from "../../components/Button";
import Alert from "./components/Alert";

//assets
import qrBgImage from "./qr-bg.svg";
import desktopQrBgImage from "./desktop-qr-bg.svg";
import bookImage from "./book.svg";
import cameraIcon from "./camera.svg";

function Activation({ headerOptions, setHeaderOptions, isMobile }) {
  useEffect(() => {
    setHeaderOptions(headerOptions);
  }, []);
  return (
    <div className="w-full flex h-full flex-col bg-transparent lg:pt-36 lg:pb-24">
      <Header
        bg={isMobile ? qrBgImage : desktopQrBgImage}
        text={window.t("فعال‌سازی کتاب دیجیتال")}
        title=""
      />
      <div className="flex-1 flex flex-col justify-between lg:justify-start px-4 lg:w-1/4 lg:mx-auto">
        <div className="flex flex-col items-center transform -translate-y-12">
          <img src={bookImage} alt="" className="w-1/4 lg:hidden" />
          <Alert
            text={window.t(
              "دانش آموز گرامی پس از خرید فیزیکی کتاب، یک کارت فعالسازی در درون کتاب قرار داده شده که شما می‌توانید با وارد کردن کد در قسمت زیر و یا اسکن کد QR با دوربین موبایل خود اقدام به فعالسازی امکانات ویژه برای کتاب خود نمائید"
            )}
          />
        </div>
        <div className="flex flex-col lg:transform lg:-translate-y-8">
          <input
            type="text"
            className="w-full bg-grayF9 rounded-md text-center text-sm lg:text-tiny placeholder-gray-500 dark:placeholder-gray-400 py-3 placeholder-opacity-40 mb-4 text-blueC0 transition-all dark:bg-opacity-10 dark:text-white border border-solid border-gray-300"
            title={window.t("کد فعال سازی")}
          />
          <Button
            title={window.t("تایید کد")}
            backgroundColor="bg-blueC0"
            border={{ color: "#196EC055", width: "1px" }}
            width="100%"
            color="text-white"
            onClick={() => {}}
          />
          <OR />
          <button className="w-full bg-blueCB rounded-md text-center text-sm py-3 lg:py-4 lg:text-tiny mb-4 text-white relative dark:bg-opacity-60">
            {window.t("فعال سازی با کد QR")}
            <img
              src={cameraIcon}
              alt=""
              className="transform -translate-y-1/2 absolute left-2 top-1/2 w-8"
            />
          </button>
        </div>
      </div>
    </div>
  );
}

const mapStateToProps = (state) => ({
  isMobile: state.publicApi.isMobile,
});

const mapDispatchToProps = {
  setHeaderOptions: publicApi.setHeaderOptions,
};

export default connect(mapStateToProps, mapDispatchToProps)(Activation);
