import React, { useState, useEffect } from "react";
import { useNavigate } from "react-router-dom";
import onInput from "../../../utils/onInput";
import { user, file, publicApi } from "../../../redux/actions";
import { connect } from "react-redux";

import Select from "../../../components/Select";
import Input from "../../../components/Input";
import TextArea from "../../../components/Textarea";
import Upload from "./Upload";
import Gender from "./GenderSwitch";
import Birthdate from "./Birthdate";
import MultipleSelector from "./MultipleSelector";
import Document from "./Document";

function Profile({
  isMobile,
  profile,
  uploads,
  getProvince,
  getCity,
  setDone,
  upload,
  setProfile,
  province,
  provinceList,
  cityList,
  setHeaderOptions,
}) {
  let navigate = useNavigate();
  const [render, setRender] = useState(false);
  const [formData, setFormData] = useState({
    file: uploads["file"] || profile.picFileId || null,
    picFileId: uploads["file"] || profile.picFileId || null,
    docFileIds: uploads["docFileIds"] || profile.docFileIds || "",
    firstName: profile.firstName || "",
    lastName: profile.lastName || "",
    password: profile.password || "",
    username: profile.username || "",
    address: profile.address || "",
    email: profile.email || "",
    birthDate: profile.birthDate || "",
    gender: profile.gender || 1,
    status: profile.status || 1,
    nationalId: profile.nationalId || "",
    phone: profile.phone || "",
    schools: profile.schools || null,
    zoneId: profile.zoneId || "",
    schoolId: profile.schoolId || "",
    postalCode: profile.postalCode || "",
    gradeIds: profile.gradeIds || [],
    provinceId: profile.provinceId || null,
    cityId: profile.cityId || null,
  });

  useEffect(() => {
    setHeaderOptions({
      logo: true,
      hamburgerMenu: true,
      qr: true,
      title: false,
      back: false,
      shown: true,
      menu: false,
    });
    getProvince();
    getCity({ provinceId: profile.provinceId });
  }, []);

  useEffect(() => {
    if (setDone) {
      navigate("/");
    }
  }, [setDone]);

  const grades = [
    {
      name: window.t("پیش دبستانی"),
      value: 0,
    },
    {
      name: window.t("اول"),
      value: 1,
    },
    {
      name: window.t("دوم"),
      value: 2,
    },
    {
      name: window.t("سوم"),
      value: 3,
    },
    {
      name: window.t("چهارم"),
      value: 4,
    },
    {
      name: window.t("پنجم"),
      value: 5,
    },
    {
      name: window.t("ششم"),
      value: 6,
    },
    {
      name: window.t("هفتم"),
      value: 7,
    },
    {
      name: window.t("هشتم"),
      value: 8,
    },
    {
      name: window.t("نهم"),
      value: 9,
    },
    {
      name: window.t("دهم"),
      value: 10,
    },
    {
      name: window.t("یازدهم"),
      value: 11,
    },
    {
      name: window.t("دوازدهم"),
      value: 12,
    },
  ];

  const onChange = (name, value) => {
    if (name === "provinceId") {
      getCity({ provinceId: value });
      setFormData({ ...formData, cityId: null, [name]: value });
    } else if (name === "status") {
      setFormData({
        ...formData,
        gradeIds: formData.gradeIds?.slice(0, 1) || [],
        [name]: value,
      });
    } else if (name === "docFileIds") {
      upload({ file: value, target: name });
      setFormData({ ...formData, [name]: value });
    } else if (name === "file") {
      upload({ file: value, target: name });
      setFormData({ ...formData, [name]: value });
    } else {
      setFormData({ ...formData, [name]: value });
    }
  };

  const onSubmit = async () => {
    const {
      firstName,
      lastName,
      username,
      //cellphone,
      password,
      postalCode,
      address,
      email,
      phone,
      picFileId,
      gender,
      nationalId,
      birthDate,
      schools,
      gradeIds,
      status,
      provinceId,
      cityId,
      docFileIds,
    } = formData;
    const data = {
      firstName: firstName || profile.firstName,
      lastName: lastName || profile.lastName,
      username: username || profile.username,
      cellphone: profile.cellphone,
      password: password || profile.password,
      postalCode: postalCode || profile.postalCode,
      address: address || profile.address,
      email: email || profile.email,
      phone: phone || profile.phone,
      nationalId: nationalId || profile.nationalId,
      picFileId: uploads["file"] || picFileId || profile.picFileId,
      gender: gender || profile.gender,
      birthDate: birthDate || profile.birthDate,
      schools: schools || profile.schools,
      gradeIds: gradeIds || profile.gradeIds,
      status: status || profile.status,
      provinceId: provinceId || profile.provinceId,
      cityId: cityId || profile.cityId,
      docFileIds: uploads["docFileIds"] || docFileIds || profile.docFileIds,
    };
    await setProfile(data);
  };

  // if (setDone) return <Navigate path="/" />;

  return isMobile ? (
    <div className="profile main d-flex justify-content-center">
      <main>
        <header className="d-flex align-items-center justify-content-between">
          <div>
            <h1>{window.t("حساب کاربری")}</h1>
            <p>{window.t("لطفا مشخصات خود را به صورت کامل نمایید.")}</p>
          </div>
          <div className="mobile justify-content-center">
            <Upload
              name="file"
              value={formData.file}
              onChange={onChange}
              label={window.t("فایل")}
            />
          </div>
        </header>
        <div className="profile__box d-flex" onSubmit={(e) => onSubmit()}>
          <div className="profile__box--section">
            <div className="mb-2 desktop justify-content-center">
              <Upload
                name="file"
                value={formData.file}
                onChange={onChange}
                label={window.t("فایل")}
              />
            </div>
            <div className="mb-2">
              <Input
                name="firstName"
                label={window.t("نام")}
                align="right"
                onInput={onInput.persianOnly}
                defaultValue={formData}
                onChange={onChange}
                // ref={usernameInput}
              />
            </div>
            <div className="mb-2">
              <Input
                name="lastName"
                label={window.t("نام نام خانوادگی")}
                align="right"
                defaultValue={formData}
                onChange={onChange}
                onInput={onInput.persianOnly}
              />
            </div>
            <div className="mb-2">
              <Input
                name="username"
                label={window.t("نام کاربری")}
                defaultValue={formData}
                onChange={onChange}
                align="left"
                onInput={onInput.englishAndNumberWithoutSpace}
              />
            </div>
            <div className="mb-2">
              <Gender
                options={[window.t("دختر"), window.t("دانش پسر")]}
                name="gender"
                selectedOption={formData.gender}
                onChange={onChange}
                label=""
              />
            </div>
            <div className="mb-2">
              <Input
                name="nationalId"
                label={window.t("کد ملی/اتباع")}
                align="left"
                maxLength={13}
                defaultValue={formData}
                onChange={onChange}
                onInput={onInput.numberOnly}
              />
            </div>
            <div className="mb-2">
              <Birthdate
                defaultValue={formData}
                name="birthDate"
                onChange={onChange}
              />
            </div>
            <div className="mb-2">
              <Input
                name="password"
                label={window.t("رمز عبور")}
                onChange={onChange}
                align="left"
                onInput={onInput.englishAndNumberWithoutSpace}
              />
            </div>
          </div>
          <div className="profile__box--section">
            <div className="mb-2" style={{ minWidth: "100%" }}>
              <Gender
                options={[window.t("معلم"), window.t("دانش آموز")]}
                name="status"
                label={window.t("عنوان")}
                selectedOption={formData.status}
                onChange={onChange}
              />
            </div>
            {formData.status === 1 ? (
              <div className="mb-2">
                <Select
                  options={grades}
                  name="gradeIds"
                  label={window.t("پایه تحصیلی")}
                  selectedOptions={formData.gradeIds}
                  onChange={onChange}
                />
              </div>
            ) : null}
            {formData.status === 2 ? (
              <div className="mb-2">
                <MultipleSelector
                  options={grades}
                  name="gradeIds"
                  label={window.t("پایه تحصیلی")}
                  selectedOptions={formData.gradeIds}
                  onChange={onChange}
                  align="right"
                  defaultValue={profile}
                />
              </div>
            ) : null}

            {formData.status === window.t("دانش آموز") &&
            formData.gradeIds > 9 ? (
              <div className="mb-2">
                <Select
                  options={[
                    window.t("ریاضی"),
                    window.t("تجربی"),
                    window.t("انسانی"),
                    window.t("فنی حرفه‌ای"),
                    window.t("کاردانش"),
                    window.t("معارف"),
                  ]}
                  name="field"
                  label={window.t("رشته تحصیلی")}
                  selectedOptions={formData.gradeIds}
                  onChange={onChange}
                />
              </div>
            ) : null}
            <div className="mb-2" style={{ minWidth: "100%" }}>
              <Select
                options={provinceList}
                name="provinceId"
                label={window.t("استان")}
                selectedOptions={formData.provinceId}
                onChange={onChange}
              />
            </div>
            <div className="mb-2">
              <Select
                options={cityList}
                name="cityId"
                label={window.t("شهرستان")}
                selectedOptions={formData.cityId}
                onChange={onChange}
              />
            </div>
            {formData.status == 1 ? (
              <div className="mb-2">
                <Input
                  name="schools"
                  label={window.t("نام مدرسه")}
                  defaultValue={formData}
                  onInput={onInput.persianOnly}
                  onChange={onChange}
                />
              </div>
            ) : null}
            {formData.status == 2 ? (
              <div className="mb-2">
                <Input
                  name="schools"
                  label={window.t("محل تدریس")}
                  defaultValue={formData}
                  onInput={onInput.persianOnly}
                  onChange={onChange}
                />
              </div>
            ) : null}
            {formData.status == 2 ? (
              <Document
                onChange={onChange}
                defaultValue={formData}
                name="docFileIds"
              />
            ) : null}
            <div className="mb-2">
              <Input
                name="postalCode"
                placeholder={window.t("کد پستی")}
                align="left"
                onChange={onChange}
                maxLength={10}
                inputMode="numeric"
                defaultValue={formData}
                onInput={onInput.numberOnly}
              />
            </div>
            <div className="mb-2">
              <TextArea
                placeholder={window.t("آدرس محل سکونت")}
                name="address"
                defaultValue={formData}
                onChange={onChange}
              />
            </div>
            <div className="profile__box--form__footer d-flex justify-content-center">
              <button onClick={() => onSubmit()}>{window.t("ذخیره")}</button>
            </div>
          </div>
        </div>
      </main>
    </div>
  ) : (
    <ul className="flex flex-col flex-1">
      <li className="flex flex-row gap-5">
        <div className="flex flex-col w-4/12">
          <strong>{window.t(" اطلاعات هویتی")}</strong>
          <p>
            {window.t(
              " لطفا نام و نام خانوادگی خود را به طور کامل وارد نمایید"
            )}
          </p>
        </div>
        <div className="flex flex-row w-8/12"></div>
      </li>
    </ul>
  );
}

export default connect(
  (state) => ({
    profile: state.user.status,
    setDone: state.user.setDone,
    loading: state.user.loading,
    uploading: state.file.loading,
    uploads: state.file.uploads,
    provinceList: state.publicApi.province,
    cityList: state.publicApi.city,
    isMobile: state.publicApi.isMobile,
  }),
  {
    getProfile: user.getProfile,
    setProfile: user.setProfile,
    upload: file.upload,
    getProvince: publicApi.getProvince,
    getCity: publicApi.getCity,
    setHeaderOptions: publicApi.setHeaderOptions,
  }
)(Profile);

Profile.defaultProps = {
  user: {
    name: window.t("اکبر"),
    icon: "",
    description: "",
  },
};
