import React, { useMemo, useEffect, useCallback } from "react";
import { connect } from "react-redux";
import {
  userProduct,
  comment,
  file,
  form,
  dialog,
} from "../../../redux/actions";
import onInput from "../../../utils/onInput";

//components
import Input from "../../../components/Input";
import Textarea from "../../../components/Textarea";
import Button from "../../../components/Button";
import Select from "../../../components/Select";
import Upload from "./Upload";

export const Ticket = ({
  isDark,
  myProductList,
  status,
  ticket,
  getUserProductList,
  submit,
  upload,
  setTicket,
  grades,
  setDialog,
}) => {
  let opt = useMemo(
    () => [
      window.t("واحد مورد نظر"),
      window.t("واحد فروش"),
      window.t("واحد فنی"),
      window.t("واحد محتوایی"),
    ],
    [status]
  );

  useEffect(() => {
    if (myProductList.length === 0 && status) {
      getUserProductList();
    }
  }, []);

  const addFile = useCallback(
    (name, value) => {
      upload({ file: value, target: name });
      setTicket({ name, value });
    },
    [status]
  );

  const send = useCallback(async () => {
    if (!ticket?.subject) {
      setDialog({
        text: window.t("موضوع پیام خود را وارد کنید."),
        type: "alert",
        accept: () => {},
        open: true,
      });
    } else if (!ticket?.unit) {
      setDialog({
        text: window.t("واحد مورد نظر خود را وارد نکرده اید."),
        type: "alert",
        accept: () => {},
        open: true,
      });
    } else {
      const data = {
        fileId: null,
        text: ticket?.text,
        name: !status ? ticket?.name : status.firstName + " " + status.lastName,
        cellphone: !status ? ticket?.cellphone : status?.cellphone,
        unit: ticket?.unit,
        bookId: ticket?.bookId,
        subject: ticket?.subject,
        userId: status?.userId,
      };
      await submit(data);
    }
  }, [status, ticket]);

  useEffect(() => {
    window.scrollTo(0, 0);
  }, []);

  return (
    <div className="flex flex-col flex-1">
      {!status && (
        <>
          <Input
            width="100%"
            label="نام و نام خانوادگی"
            name="name"
            onChange={(name, value) => setTicket({ name, value })}
            value={ticket?.name || ""}
            regex={(val) => val}
          />
          <Input
            width="100%"
            label="شماره تماس"
            name="cellphone"
            onChange={(name, value) => setTicket({ name, value })}
            value={ticket?.cellphone || ""}
            regex={(val) => onInput.phonenumber(val)}
            maxLength="11"
          />
        </>
      )}
      <Select
        options={status && myProductList?.length ? opt : opt.slice(0, 3)}
        name="unit"
        onChange={(name, value) => setTicket({ name, value })}
        width={"w-full"}
        backgroundColor={isDark ? "dark:bg-transparent dark:text-white" : ""}
        fill={isDark ? "fill-white" : "fill-gray-600"}
      />
      {ticket?.unit === window.t("1400/11/24") && (
        <>
          <div className="mt-2"></div>
          <Select
            name="bookId"
            options={[
              ...new Set(
                myProductList?.map((item) => [
                  item?.product?.book?.id,
                  `${item?.product?.book.name} {window.t("پایه")}  ${
                    Object.values(grades)[item.product.book.gradeId]
                  }`,
                ]) || []
              ),
            ]}
            onChange={(name, value) => setTicket({ name, value })}
            width={"w-full"}
            backgroundColor={
              isDark ? "dark:bg-transparent dark:text-white" : ""
            }
            fill={isDark ? "fill-white" : "fill-gray-600"}
          />
        </>
      )}
      <Input
        width="100%"
        name="subject"
        onChange={(name, value) => setTicket({ name, value })}
        value={ticket?.subject || ""}
        regex={(val) => val}
        label={window.t("موضوع")}
      />
      <Textarea
        placeholder={window.t("پیام خود را اینجا بنویسید")}
        name="text"
        onChange={(name, value) => setTicket({ name, value })}
        value={ticket?.text || ""}
      />
      <br />
      <Upload
        onChange={(name, value) => addFile(name, value)}
        name="file"
        value={ticket?.file}
      />
      <br />
      <Button
        title={window.t("ارسال پیام")}
        backgroundColor={isDark ? "bg-blueC0" : "bg-blueC0"}
        border={{ color: isDark ? "#ffffff55" : "#196EC055", width: "0px" }}
        width="100%"
        color={"text-white"}
        selectable={true}
        onClick={() => send()}
      />
    </div>
  );
};

const mapStateToProps = (state) => ({
  isDark: state.publicApi.isDark,
  myProductList: state.userProduct.myList,
  status: state.user.status,
  ticket: state.form.ticket,
  grades: state.publicApi.grades,
});

const mapDispatchToProps = {
  getUserProductList: userProduct.myList,
  submit: comment.add,
  upload: file.upload,
  setTicket: form.setTicket,
  setDialog: dialog.set,
};

export default connect(mapStateToProps, mapDispatchToProps)(Ticket);
