import React, { useEffect } from "react";
import { connect } from "react-redux";
import { Link } from "react-router-dom";

import Product from "../../../../../components/Product";
import ProductSuggestion from "../UserItems/ProductSuggestion";
import { ScrollingCarousel } from "@trendyol-js/react-carousel";
import { Book } from "../../../../Home/Portrait/Private/MyBooks";
import Progress from "../../../../../components/Progress";

export const MyBooks = ({ books, grades, isMobile }) => {
  const Book = ({ book }) => {
    return (
      <li className=" flex flex-col lg:ml-6 lg:p-2 lg:border lg:border-solid lg:border-green-200 lg:rounded-md lg:pt-4">
        <Link to={"/products/" + book.id}>
          <img
            src={`https://dnvn.ir/api/v1/file/${book.fileIds}`}
            alt=""
            className="rounded-sm"
            style={{
              height: isMobile ? "" : "calc(100vh / 4)",
              width: isMobile ? "" : "calc(100vh / 4 * 3 / 4)",
              minHeight: isMobile ? "calc(100vh / 5)" : "",
              minWidth: isMobile ? "calc(100vh / 5 * 3 / 4)" : "",
              maxHeight: isMobile ? 100 : "",
              maxWidth: isMobile ? 70 : "",
            }}
          />
          <h2 className="mt-2 text-tiny lg:text-tiny font-semibold text-blue5F dark:text-white lg:mt-4">
            {book.name}
          </h2>
          <p className="font-medium text-green7B dark:text-greenBA text-sm lg:text-sm mt-2 lg:mt-2">{`پایه ${
            grades[book.gradeId]
          }`}</p>
          <Progress percent={60} direction="float-right" />
        </Link>
      </li>
    );
  };

  useEffect(() => {
    window.scrollTo(0, 0);
  }, []);

  return (
    <div className="flex flex-1 flex-col">
      <div className="flex flex-wrap gap-4 mb-5 ">
        {/* {books.slice(0, 1).map((product, index) => (
          <Product key={index} product={product} imageSdize={5} />
        ))} */}
        <div className="w-full scrolling-carousel mt-4 pb-2">
          <p className="text-green7B  font-bold text-2xl lg:text-base">
            {window.t("کتاب های من")}
          </p>
          <ScrollingCarousel className="py-3">
            {books?.map((book, index) => (
              <Book book={book} key={index} />
            ))}
          </ScrollingCarousel>
        </div>
      </div>
      <ProductSuggestion products={books} grades={grades} isMobile={isMobile} />
    </div>
  );
};

const mapStateToProps = (state) => ({
  books: state.book.list,
  grades: state.publicApi.grades,
  isMobile: state.publicApi.isMobile,
});

const mapDispatchToProps = {};

export default connect(mapStateToProps, mapDispatchToProps)(MyBooks);
