import React, { useEffect } from "react";
import separate from "../../../utils/separate";
import { connect } from "react-redux";
import { transport } from "../../../redux/actions";

//components
import Loading from "../../../components/Loading";
import ButtonBetween from "../../../components/ButtonBetween";

function TransportMethod({
  list,
  isMobile,
  setTransport,
  getList,
  factorInfo,
  userId,
  loading,
}) {
  useEffect(() => {
    if (list.length === 0) {
      getList();
    }
  }, []);

  const Method = ({ method, active }) => {
    return isMobile ? (
      <ButtonBetween
        width={"100%"}
        onClick={() =>
          !active
            ? setTransport(
                { factorId: factorInfo?.id, transportId: method?.id },
                { userId },
                {}
              )
            : {}
        }
        item={"ارسال با" + " " + method.name}
        status={separate(method.price) + " " + "تومان"}
        active={active}
        toggle={true}
      />
    ) : (
      <button
        className={`flex flex-col border border-solid items-center px-2 py-3 rounded-md mt-4 relative transition-all duration-500 w-2/5 ${
          factorInfo?.transportId === method?.id
            ? "bg-blueC0 bg-opacity-5 border-blueC0 dark:bg-opacity-5"
            : "bg-grayF9 border-grayDB dark:bg-opacity-5"
        }`}
        onClick={() =>
          !active
            ? setTransport(
                { factorId: factorInfo?.id, transportId: method?.id },
                { userId },
                {}
              )
            : {}
        }
      >
        {loading && !active ? (
          <Loading size={4} color={active ? "bg-green-500" : "bg-gray-500"} />
        ) : (
          <strong
            className={`text-tiny transition-all duration-500 ${
              active
                ? "text-green7B dark:text-white"
                : "text-blue52 dark:text-white"
            }`}
          >
            {method.name}
          </strong>
        )}
        <span
          className={`text-sm transition-all duration-500 mt-2 ${
            active
              ? "text-green7B dark:text-white"
              : "text-blue52 dark:text-white"
          }`}
        >
          هزینه ارسال &nbsp; {separate(method.price)}
        </span>
      </button>
    );
  };
  return isMobile ? (
    <section className="mt-0 w-full">
      <strong className="text-green7B font-bold dark:text-white text-base">
        لطفا یک روش ارسال انتخاب کنید
      </strong>
      <ul className="list-none p-0 m-0 flex flex-col gap-4 w-full mt-5">
        {list.map((method, index) => (
          <Method
            method={method}
            key={index}
            active={factorInfo?.transportId === method?.id}
          />
        ))}
      </ul>
    </section>
  ) : (
    <section className="mt-1 w-full">
      <strong className="font-medium dark:text-white">
        لطفا یک روش ارسال انتخاب کنید
      </strong>
      <ul className="list-none p-0 m-0 flex flex-row gap-5 flex-wrap">
        {list.map((method, index) => (
          <Method
            method={method}
            key={index}
            active={factorInfo?.transportId === method?.id}
          />
        ))}
      </ul>
    </section>
  );
}

const mapStateToProps = (state) => ({
  list: state.transport.list,
  isDark: state.publicApi.isDark,
  isMobile: state.publicApi.isMobile,
  factorInfo: state.userFactor.info,
  userId: state.user.status?.id,
  loading: state.transport.loading,
});

const mapDispatchToProps = {
  getList: transport.list,
  setTransport: transport.set,
};

export default connect(mapStateToProps, mapDispatchToProps)(TransportMethod);
