import React, { useEffect } from "react";
import { connect } from "react-redux";
import { publicApi, userFactor, userAddress } from "../../redux/actions";
import Address from "./Address";
import TransportMethod from "./TransportMethod";
import TransportDate from "./TransportDate";
import PaymentMethods from "./PaymentMethod";
//assets
import ExpressIcon from "../../assets/icons/express.svg";
import PishtazIcon from "../../assets/icons/pishtaz.svg";
import arrowBlueIcon from "../../assets/icons/arrow-right-blue.svg";
import arrowWhiteIcon from "../../assets/icons/arrow-left-white.svg";

export const DeliveryForm = ({
  getList,
  list,
  setHeaderOptions,
  headerOptions,
  form,
  factorInfo,
  getFactorInfo,
  userId,
  isDark,
  isMobile,
  setPhase,
}) => {
  useEffect(() => {
    if (isMobile) {
      setHeaderOptions({ shown: false });
    }
    getFactorInfo({ userId });
    getList();
  }, []);

  const PriceStatus = ({ name, value, type }) => {
    return (
      <div className="w-full flex flex-row justify-between py-2">
        <strong className="font-light text-sm dark:text-white">{name}</strong>
        <span
          className="font-bold text-sm dark:text-white"
          style={{
            color: !isDark ? (type === "error" ? "#F1420D" : "#246E8A") : "",
          }}
        >
          {value + " " + "تومان"}
        </span>
      </div>
    );
  };

  return isMobile ? (
    <div className="w-full flex flex-col pt-4 pb-4">
      <div className="w-full flex flex-row gap-5">
        <Address addresses={list} setPhase={setPhase} />
      </div>
      <div className="w-full flex flex-row gap-5 mt-8">
        <TransportMethod />
      </div>
      <div className="w-full flex flex-row gap-5 mt-8">
        <TransportDate transportDate={form.transportDate} />
      </div>
      {isMobile && (
        <div
          className="fixed top-0 left-0  flex justify-between items-center py-3 px-4 w-full"
          style={{
            backgroundColor: isDark ? "#061B30" : "white",
          }}
        >
          <strong className="text-green4F text-lg font-semibold dark:text-white">
            تکمیل اطلاعات
          </strong>
          <img
            src={isDark ? arrowWhiteIcon : arrowBlueIcon}
            alt="back"
            className={`w-6 transform ${isDark ? " rotate-0" : "rotate-180"}`}
            onClick={() => setPhase("products")}
          />
        </div>
      )}
    </div>
  ) : (
    <div className="w-full flex flex-col px-4 pb-10">
      <div className="w-full flex flex-row gap-5">
        <span className="w-6 h-6 rounded-full bg-grayF4 flex justify-center items-center text-sm">
          1
        </span>
        <Address addresses={list} setPhase={setPhase} />
      </div>
      <div className="w-full flex flex-row gap-5 mt-8">
        <span className="w-6 h-6 rounded-full bg-grayF4 flex justify-center items-center text-sm">
          2
        </span>
        <TransportMethod />
      </div>
      {/* <div className="w-full flex flex-row gap-5 mt-8">
        <span className="w-6 h-6 rounded-full bg-grayF4 flex justify-center items-center text-sm">
          3
        </span>
        <TransportDate transportDate={form.transportDate} />
      </div> */}
    </div>
  );
};

const mapStateToProps = (state) => ({
  factorInfo: state.userFactor.info,
  userId: state.user.status.id,
  isDark: state.publicApi.isDark,
  isMobile: state.publicApi.isMobile,
  list: state.userAddress.list,
});

const mapDispatchToProps = {
  setHeaderOptions: publicApi.setHeaderOptions,
  getFactorInfo: userFactor.info,
  getList: userAddress.list,
};

export default connect(mapStateToProps, mapDispatchToProps)(DeliveryForm);

DeliveryForm.defaultProps = {
  form: {
    addresses: [
      {
        address:
          " تهران میدان احمد آباد خیابان شریعتی بعد از میدان فجر بن بست شکوفه پلاک 4 زنگ 12",
        receiver: "احمد نام آور",
        postalCode: "54352432",
        cellphone: "09123456789",
      },
    ],
    transportMethods: [
      {
        name: "ارسال اکسپرس مخصوص شهر تهران",
        cost: "25.000",
        icon: ExpressIcon,
      },
      {
        name: "ارسال با پست پیشتاز",
        cost: "25.000",
        icon: PishtazIcon,
      },
    ],
    transportDate: {
      day: new Date(),
      times: [
        {
          time: "ساعت 9 تا 12",
          status: "completed",
        },
        {
          time: "ساعت 12 تا 15",
          status: "free",
        },
        {
          time: "ساعت 15 تا 18",
          status: "free",
        },
      ],
    },
    paymentMethods: [
      {
        name: "پرداخت آنلاین با کلیه کارت‌های عضو شبکه شتاب",
      },
      {
        name: "پرداخت در محل",
      },
    ],
  },
};
