import React, { useEffect } from "react";
import { connect } from "react-redux";
import { faq, publicApi } from "../../redux/actions";

import Header from "../Activation/components/Header";
import Question from "./components/Question";
import NotFound from "./components/NotFound";
import Search from "../../components/Search";

//assets
import faqBgImage from "./faq-bg.svg";
import desktopFaqBgImage from "./desktop-faq-bg.svg";
import searchLight from "../../assets/icons/search-light.svg";

function Faq({ headerOptions, setHeaderOptions, isMobile, list, getList, selectFaq }) {
  useEffect(() => {
    setHeaderOptions(headerOptions);
    getList();
  }, []);
  return (
    <div
      className="w-full flex h-full flex-col bg-transparent lg:pt-36 lg:pb-24"
      // style={{ height: "calc(100vh - 145px)" }}
    >
      <Header
        bg={isMobile ? faqBgImage : desktopFaqBgImage}
        title="پرسش‌های متداول"
      />

      <div className="w-full flex flex-col px-4 transform -translate-y-12 items-center">
        <div className="lg:w-1/2 w-full">
          {isMobile && (
            <Search
              backgroundColor="bg-grayF9 dark:bg-gray2077"
              borderColor="border-grayDB dark:border-gray45"
              textColor="text-blueC0 dark:text-white"
              icon={searchLight}
            />
          )}
          {list?.map((item, index) => (
            <Question key={index} item={item} selectFaq={selectFaq} />
          ))}
        </div>
        <div className="w-full flex flex-row lg:w-4/5 justify-end">
          <NotFound
            title={"پرسش خود را در لیست بالا پیدا نکردید؟"}
            subTitle={"برای ما پیام ارسال کنید"}
            link="/contact-us"
          />
        </div>
      </div>
    </div>
  );
}

const mapStateToProps = (state) => ({
  isMobile: state.publicApi.isMobile,
  list : state.faq.list,
  active : state.faq.active
});

const mapDispatchToProps = {
  setHeaderOptions: publicApi.setHeaderOptions,
  getList: faq.list,
  selectFaq: faq.selectFaq
};
export default connect(mapStateToProps, mapDispatchToProps)(Faq);
