import React, { useState, useEffect } from "react";
import { connect } from "react-redux";
import { Link } from "react-router-dom";
import { Carousel } from "@trendyol-js/react-carousel";
import Book from "./Book";
import FloatWithMouse from "../../../../components/FloatWidthMouse";
import Lights from "./Lights";

import _ from "lodash";

import olum1Image from "../../../../assets/images/olum-1.svg";
import olum2Image from "../../../../assets/images/olum-2.svg";
import olum4Image from "../../../../assets/images/olum-4.svg";
import olum7Image from "../../../../assets/images/olum-7.svg";
import zist11Image from "../../../../assets/images/zist-11.svg";
import arrow from "../../../../assets/icons/slider-arrow.svg";
import flatFlower from "../../../../assets/icons/flat-flower-white.svg";
import line from "../../../../assets/icons/line.svg";
import arrowBottomIcon from "../../../../assets/icons/arrows-bottom-blue.svg";
import sheffImage from "../../../../assets/images/sheff.svg";
import arrowLeftWhite from "../../../../assets/icons/arrow-left-white.svg";

function Page1({ list, top }) {
  const [show, setShow] = useState(null);

  useEffect(() => {
    const width = window.innerWidth;
    window.addEventListener(
      "resize",
      _.debounce(() => {
        if (width > 1536) {
          setShow(5);
        } else if (width > 1024) {
          setShow(4);
        }
      }, 100)
    );
    if (width > 1536) {
      setShow(5);
    } else if (width > 1024) {
      setShow(4);
    }
  }, []);

  return (
    <div
      className={_.join(
        [
          "home-page1 w-full flex flex-col justify-center items-center h-screen fixed left-0 px-6",
        ],
        " "
      )}
      style={{ top: top }}
    >
      <FloatWithMouse />
      <Lights />
      <img
        src={flatFlower}
        alt=""
        className="absolute transform left-1/2 top-1/2 -translate-x-1/2 -translate-y-1/2"
      />
      <img
        src={line}
        alt=""
        className="absolute transform left-1/2 top-1/2 -translate-x-1/2 -translate-y-1/2"
      />
      <div className="container flex flex-col lg:px-8">
        <div className="w-full relative z-10 px-4" style={{ direction: "ltr" }}>
          <Carousel
            show={show}
            slide={2}
            swiping={true}
            // useArrowKeys={true}
            transition={0.5}
            rightArrow={
              <img
                className="absolute top-1/2 transform -translate-y-1/2 cursor-pointer"
                src={arrow}
                alt=""
              />
            }
            leftArrow={
              <img
                className="absolute top-1/2 transform -translate-y-1/2 -translate-x-5 cursor-pointer -rotate-180"
                src={arrow}
                alt=""
              />
            }
          >
            {list.map((book, index) => (
              <Book book={book} key={index} />
            ))}
          </Carousel>
        </div>
      </div>
      <div className="w-full relative lg:px-8">
        <img
          src={sheffImage}
          alt=""
          className="absolute bottom-0 left-1/2 transform -translate-x-1/2 translate-y-7"
        />
      </div>
      <div
        className="container flex flex-row justify-between relative transform translate-y-12"
        style={{ alignItems: "start" }}
      >
        <div className="list-none flex flex-row bg-blueB0 bg-opacity-40 p-2.5 rounded-md backdrop-filter backdrop-blur-md">
          <strong className="text-white text-sm font-light ml-1 border-l-2 pl-2 border-gray-300">
            لیست محصولات
          </strong>
          <Link to="/products" className="text-white text-xs mr-5">
            کتاب ها
          </Link>
          <Link to="/products" className="text-white text-xs mr-5">
            دوره ویديویی
          </Link>
          <Link to="/products" className="text-white text-xs mr-5">
            آزمون ها
          </Link>
        </div>
        <div className="flex flex-col">
          <h1 className="text-xl font-semibold text-blueC0">
            لذت یادگیری را با دانوین تجربه کنید
          </h1>
          <p className="text-blue5F font-light text-sm w-64 mt-1 text-justify">
            ما در دانوین با هدف ایجاد زیرساخت تعاملی و آموزشی با تولید محتوایی
            جذاب بصورت کتاب قصد داریم تغییراتی بنیادین در نظام آموزش و پرورش
            کشور ایجاد کنیم.
          </p>
          <Link
            to="/products"
            className="flex flex-row items-center text-white text-xs bg-blueC0  px-4 py-3 rounded-md backdrop-filter backdrop-blur-md mt-5 self-end animate-bounce"
          >
            ورود به فروشگاه <img src={arrowLeftWhite} alt="" className="mr-2" />
          </Link>
        </div>
      </div>

      <img
        src={arrowBottomIcon}
        alt=""
        className="absolute transform left-1/2 bottom-5 -translate-x-1/2 cursor-pointer"
      />
    </div>
  );
}

const mapStateToProps = (state) => ({
  top: state.scrollAction.page1TopPosition,
});

export default connect(mapStateToProps, {})(Page1);

Page1.defaultProps = {
  list: [
    {
      name: "زیست یازدهم",
      imageUrl: zist11Image,
    },
    {
      name: "علوم دوم",
      imageUrl: olum2Image,
    },
    {
      name: "علوم اول",
      imageUrl: olum1Image,
    },
    {
      name: "علوم هفتم",
      imageUrl: olum7Image,
    },
    {
      name: "علوم چهارم",
      imageUrl: olum4Image,
    },
    {
      name: "علوم چهارم",
      imageUrl: olum4Image,
    },
    {
      name: "علوم چهارم",
      imageUrl: olum4Image,
    },
  ],
};
