import React from "react";
import { Link } from "react-router-dom";
import { connect } from "react-redux";
import { ScrollingCarousel } from "@trendyol-js/react-carousel";
import Progress from "../../../../../components/Progress";

function MyBooks({ books, grades, isMobile }) {
  const Book = ({ book }) => {
    return (
      <li className=" flex flex-col lg:ml-6 lg:p-2 lg:border lg:border-solid lg:border-green-200 lg:rounded-md lg:pt-4">
        <Link to={"/products/" + book.id}>
          <img
            src={`https://dnvn.ir/api/v1/file/${book.fileIds}`}
            alt=""
            className="rounded-sm"
            style={{
              height: isMobile ? "" : "calc(100vh / 4)",
              width: isMobile ? "" : "calc(100vh / 4 * 3 / 4)",
              minHeight: isMobile ? "calc(100vh / 5)" : "",
              minWidth: isMobile ? "calc(100vh / 5 * 3 / 4)" : "",
              maxHeight: isMobile ? 100 : "",
              maxWidth: isMobile ? 70 : "",
            }}
          />
          <h2 className="mt-2 text-tiny lg:text-tiny font-semibold text-blue5F dark:text-white lg:mt-4">
            {book.name}
          </h2>
          <p className="font-medium text-green7B dark:text-greenBA text-sm lg:text-sm mt-2 lg:mt-2">{`پایه ${
            grades[book.gradeId]
          }`}</p>
          <Progress percent={60} direction="float-right" />
        </Link>
      </li>
    );
  };

  return (
    <div className="px-4 mb-5 lg:mb-0" style={{ maxWidth: "100%" }}>
      <div className=" w-full flex flex-col rounded-md pt-4 lg:py-5  px-2 lg:px-4  bg-opacity-5 border border-green-200 border-solid dark:bg-gray2077 dark:border-opacity-40 overflow-hidden">
        <strong className="text-green7B dark:text-white font-bold text-base lg:text-base mb-2">
          کتابهای من
        </strong>
        {isMobile ? (
          <ul className="list-none w-full overflow-x-scroll pt-2 flex flex-row lg:pt-5 lg:flex-wrap lg:overflow-y-scroll gap-3 lg:gap-10 no-scrollbar">
            {books?.slice(0, 5)?.map((book, index) => (
              <Book book={book} key={index} />
            ))}
          </ul>
        ) : (
          <div className="w-full scrolling-carousel mt-4 pb-2">
            <ScrollingCarousel className="py-3">
              {books?.map((book, index) => (
                <Book book={book} key={index} />
              ))}
            </ScrollingCarousel>
          </div>
        )}
      </div>
    </div>
  );
}

const mapStateToProps = (state) => ({
  isMobile: state.publicApi.isMobile,
});

export default connect(mapStateToProps)(MyBooks);
