import React from "react";
import { Link } from "react-router-dom";
import { connect } from "react-redux";
import { book } from "../../../../../redux/actions";
import Header from "../../../../../components/Header";

// assets

function Shop({ list, grades }) {
  return (
    <div className="w-full pr-4">
      <div className="w-full flex flex-col rounded-md py-4 overflow-hidden">
        <Header title={window.t("فروشگاه")} link="/products" />
        <ul
          className="list-none w-full overflow-x-scroll mt-3 flex flex-col flex-wrap no-scrollbar"
          style={{
            height: "calc(100vh / 4)",
          }}
        >
          {list.map((book, index) => (
            <Book
              book={book}
              key={index}
              grades={grades}
              index={Number(index)}
            />
          ))}
        </ul>
      </div>
    </div>
  );
}

const Book = ({ book, index }) => {
  return (
    <li className="flex flex-col ml-2">
      <Link to={"/products/" + book.id}>
        {index === 0 ? (
          <img
            src={`https://dnvn.ir/api/v1/file/${book.fileIds}`}
            alt=""
            className="rounded-sm"
            style={{
              width: "calc(100vh / 4 * 3 / 4.3 )",
              height: "calc(100vh / 4)",
              maxWidth: 200,
              maxHeight: 275,
            }}
          />
        ) : (
          <img
            src={`https://dnvn.ir/api/v1/file/${book.fileIds}`}
            alt=""
            className="rounded-sm mb-0"
            style={{
              width: "calc(100vh / 4 / 2 * 3 / 4.3)",
              height: "calc(100vh / 4 / 2 - 4px)",
              marginBottom: index % 2 !== 0 ? "8px" : "0px",
            }}
          />
        )}
      </Link>
    </li>
  );
};

const mapStateToProps = (state) => ({
  isDark: state.publicApi.isDark,
});

export default connect(mapStateToProps, { getList: book.list })(Shop);
