import React from "react";
import videoIcon from "../../../../../assets/icons/video.svg";
import packageIcon from "../../../../../assets/icons/packages.svg";
import testIcon from "../../../../../assets/icons/test.svg";
import interactiveIcon from "../../../../../assets/icons/interactive.svg";

function Features({ features }) {
  return (
    <div className="w-full flex flex-row flex-wrap justify-between px-2">
      {features.map((feature, index) => (
        <Feature feature={feature} key={index} />
      ))}
    </div>
  );
}

const Feature = ({ feature }) => {
  return (
    <div className="flex flex-col mt-4" style={{ width: "48%" }}>
      <div
        className="p-4 rounded-md w-16"
        style={{ backgroundColor: feature.backgroundColor }}
      >
        <img src={feature.icon} className="w-8 h-8" alt="" />
      </div>
      <strong
        className="mt-3 font-semibold text-tiny"
        style={{ color: feature.color }}
      >
        {feature.title}
      </strong>
      <p className="mt-2 font-light text-gray1 dark:text-white text-sm leading-4">
        {feature.text}
      </p>
    </div>
  );
};

export default Features;

Features.defaultProps = {
  features: [
    {
      icon: interactiveIcon,
      backgroundColor: "#FFFDC4",
      color: "#C0C700",
      title: window.t("کتاب‌های تعاملی"),
      text: window.t(
        "قابلیت امتیاز دهی به مطالب از جمله امکانات این سامانه می باشد تا به جامعه هدف کارکنان کمک نماید"
      ),
    },
    {
      icon: videoIcon,
      backgroundColor: "#A1DDFF",
      color: "#196EC0",
      title: window.t("ویدئوهای مربوط به هر درس"),
      text: window.t(
        "انتخاب رنگ در حوزه طراحی کار بسیار عجیبی است و کاربران همه روزه با آن دسته پنجه نرم می کنند"
      ),
    },
    {
      icon: testIcon,
      backgroundColor: "#C4FFF7",
      color: "#06A38E",
      title: window.t("آزمون"),
      text: window.t(
        "این پلتفرم می تواند تاریخ جشن تولد خود شما، دوستان شما و حتی خانواده شما را به شما یادآوری نمایید"
      ),
    },
    {
      icon: packageIcon,
      backgroundColor: "#FFC4EB",
      color: "#930362",
      title: window.t("پکیج ‌های آموزشی"),
      text: window.t(
        "همه پایه های تحصیلی باید توسط کاربران انتخاب شود تا به آنها اینکار را یادآوری نماید"
      ),
    },
  ],
};
