import React from "react";
import arBlue from "../../../../../assets/icons/ar-blue.svg";
import qrGreen from "../../../../../assets/icons/qr-green.svg";

function Platforms({ platforms }) {
  return (
    <div className="w-full mt-10 flex flex-col">
      {platforms.map((platform, index) => (
        <Platform platform={platform} key={index} />
      ))}
    </div>
  );
}

const Platform = ({ platform }) => {
  return (
    <div
      className="w-full flex flex-row rounded-sm p-4 items-start mb-5"
      style={{
        backgroundColor: platform.backgroundColor,
        border: `1px solid ${platform.borderColor}`,
      }}
    >
      <img src={platform.icon} alt="" className="w-8 h-8 m-1" />
      <div className="flex-1 flex flex-col pr-3">
        <strong className="text-sm" style={{ color: platform.titleColor }}>
          {platform.title}
        </strong>
        <p
          className="text-xs leading-5 mt-2"
          style={{ color: platform.textColor }}
        >
          {platform.text}
        </p>
      </div>
    </div>
  );
};

export default Platforms;

Platforms.defaultProps = {
  platforms: [
    {
      backgroundColor: "#E6F2FF",
      textColor: "#00366B",
      titleColor: "#1072DC",
      borderColor: "#196EC044",
      title: window.t("استفاده از تکنولوژی واقعیت افزوده"),
      text: window.t(
        "با استفاده از این تکنولوژی شما پس از نصب اپلیکیشن ما و گرفتن گوشیتون روی محتوای ویدئویی کتاب فیلم رو داخل گوشیتون ببینید"
      ),
      icon: arBlue,
    },
    {
      backgroundColor: "#E9FFE6",
      textColor: "#0B5900",
      titleColor: "#118A00",
      borderColor: "#118A0044",
      title: window.t("محتوای قابل دریافت  باحال و جذاب"),
      text: window.t(
        "تقریبا بالا گوشه هر صفحه از کتاب ما یک کد کیو آر براتون گذاشتیم که با اسکن کد شما می‌تونید محتویات ضمیمه شده اون رو ببینید"
      ),
      icon: qrGreen,
    },
  ],
};
