import React from "react";
import { connect } from "react-redux";
import { Link } from "react-router-dom";
import leftArrowIcon from "../../../assets/icons/dropdown-blue.svg";
import _ from "lodash";

const colors = {
  1: "#FFF700",
  4: "#FF0000",
  3: "#4CFF00",
  2: "#196EC0",
};

const status = {
  1: window.t("در حال پردازش"),
  4: window.t("درخواست رد شد"),
  3: window.t("تکمیل شد"),
  2: window.t("ارسال شده"),
};

function Order({ order, isMobile }) {
  return (
    <div className="w-full flex flex-col rounded-md overflow-hidden my-3 border border-solid border-blueC0 border-opacity-50 dark:border-blueC0 dark:border-opacity-10 lg:w-4/5 mx-auto">
      <div className="flex flex-row w-full justify-between items-center p-3 bg-blueC0 bg-opacity-10 dark:bg-blueC0 dark:bg-opacity-10">
        <strong className="font-medium text-sm lg:text-tiny text-green4F dark:text-white">
          {_.join([window.t("شماره سفارش:"), order.number], " ")}
        </strong>
        <div className="flex flex-row items-center">
          <span className="text-xs lg:text-tiny font-light text-green4F dark:text-white">
            {status[order.status]}
          </span>
          <div
            className="h-4 w-4 rounded-full mr-2"
            style={{ backgroundColor: colors[order.status] }}
          ></div>
        </div>
      </div>
      <div className="w-full flex flex-row justify-between p-3">
        <div className="flex flex-col">
          <div className="flex flex-row mb-2">
            {order.items.length < 2
              ? order?.items?.map((item, index) => (
                  <img
                    key={index}
                    src={item}
                    className="rounded-md ml-1.5"
                    style={{
                      width: isMobile ? 60 : 100,
                      height: isMobile ? 90 : 150,
                    }}
                    alt=""
                  />
                ))
              : order.items?.slice(0, 1)?.map((item, index) => (
                  <img
                    key={index}
                    src={item}
                    className="rounded-md ml-1.5"
                    style={{
                      width: isMobile ? 60 : 100,
                      height: isMobile ? 90 : 150,
                    }}
                    alt=""
                  />
                ))}
            {isMobile && order.items.length >= 2 && (
              <div
                className="flex flex-row items-center justify-center relative rounded-md overflow-hidden bg-grayEE dark:bg-gray-400"
                style={{
                  width: 60,
                  height: 90,
                }}
              ></div>
            )}
          </div>
          <div>
            <div
              className="p-2 rounded-md text-center text-xs bg-grayEE dark:bg-gray-400 dark:text-white text-blue5F lg:hidden"
              style={{
                fontFamily: "bold",
              }}
            >
              {_.join([window.t("کد تحویل:"), order.receiveCode], " ")}
            </div>
          </div>
        </div>
        <div className="flex flex-col items-center mr-4">
          <div className="hidden lg:flex w-full">
            <div
              className="py-4 rounded-md text-center text-sm dark:bg-gray-400 dark:text-white text-blue5 w-full"
              style={{
                fontFamily: "bold",
                backgroundColor: "#F0FFF1",
              }}
            >
              {_.join([window.t("کد تحویل:"), order.receiveCode], " ")}
            </div>
          </div>
          <strong
            className="my-3 text-sm bg-gray-100 py-4 rounded-md dark:bg-blueC0 dark:text-white text-blue52 lg:w-full text-center"
            style={{
              fontFamily: "bold",
            }}
          >
            {_.join([window.t("جمع فاکتور:"), order.cost], " ")}
          </strong>
          <Link
            to="/orders/order"
            className="rounded-md flex flex-row justify-center px-5 py-2.5 border border-solid border-blueC0 text-green4F bg-blueC0 bg-opacity-10"
          >
            {window.t("جزئیات سفارش")}
            <img
              src={leftArrowIcon}
              style={{ width: 18 }}
              className="transform rotate-90"
              alt=""
            />
          </Link>
          <span className="my-5 text-xs text-blue52 font-light dark:text-white lg:hidden">
            {_.join([window.t("تاریخ سفارش:"), order.date], " ")}
          </span>
        </div>
      </div>
    </div>
  );
}

const mapStateToProps = (state) => ({
  isMobile: state.publicApi.isMobile,
});

export default connect(mapStateToProps)(Order);
