import React, { useState } from "react";
import { connect } from "react-redux";
import { Link } from "react-router-dom";
import { book, userProduct, publicApi } from "../../../../redux/actions";
import Button from "../../../../components/Button";
import StarRating from "../../../../components/StarRating";
import ProductImages from "../../../../components/ProductImage";
import ProductStatusCard from "../../../../components/ProductStatusCard";
import ProductTab from "../../../../components/ProductTab";
import Table from "../../../Video/components/Desktop/Table";

//assets
import arrow from "../../../../assets/icons/dropdown-blue.svg";

export const ProductOverAll = ({ book, grades, isDark, loading }) => {
  const [type, setType] = useState("1");
  return (
    <div className="w-full flex flex-col">
      <header className={`w-full flex flex-row justify-between gap-5`}>
        <ProductImages images={book?.fileIds} />
        <div className="flex flex-col w-1/2 divide-y divide-solid divide-gray-200">
          <div className="w-full flex flex-col pr-2 py-2  border-0">
            <h1 className="text-blue5F mb-3 font-semibold text-lg dark:text-white leading-7">
              {book?.product[type]?.name}
            </h1>
            <div className="text-blueC0 text-tiny dark:text-greenBA">
              {"پایه" + " " + grades[book?.gradeId]}
            </div>
            <div className="flex justify-end items-center">
              <div className="p-2">
                <StarRating value={book?.rate || 4} />
              </div>
              <div className="p-2 border-0 border-solid border-r border-gray-100 text-sm text-gray-400">
                {window.t("بیش از")} {book?.product[type]?.suggestedCounter}
                {window.t("نفرامتیاز داده اند")}
              </div>
            </div>
          </div>
          <div className="py-4">
            <div className="w-full flex items-center pb-2">
              <h1 className="text-base font-bold">{window.t("نوع کتاب")}</h1>
              <p className=" text-xs px-4 text-blueC0">
                {window.t("به من کمک کن انتخاب کنم")}
              </p>
            </div>
            <div className="w-full flex flex-row justify-between items-center mt-4 gap-5">
              <Button
                title={window.t("نسخه فیزیکی")}
                backgroundColor={isDark ? "bg-transparent" : "bg-white"}
                border={{
                  color: isDark ? "#ffffff55" : "#aaa",
                  width: "1px",
                }}
                width="38%"
                color={isDark ? "text-white" : "text-green7B"}
                active={type === "1"}
                selectable={true}
                onClick={() => setType("1")}
                borderType="dashed"
                customStyle=""
                twPaddings="py-4 px-12"
                radius={false}
              />
              <Button
                title={window.t("نسخه دیجیتال")}
                backgroundColor={isDark ? "bg-transparent" : "bg-white"}
                border={{
                  color: isDark ? "#ffffff55" : "#196EC055",
                  width: "1px",
                }}
                width="38%"
                selectable={true}
                active={type === "0"}
                color={isDark ? "text-white" : "text-green7B"}
                onClick={() => setType("0")}
                borderType="dashed"
                radius={false}
                twPaddings="py-4 px-12"
              />
              <a
                href={`https://dnvn.ir/xpdf/${book?.sampleFileId}`}
                className="flex-1 py-4 text-sm border border-solid border-red19 rounded-md  font-bold text-red19 text-center"
              >
                {window.t("مشاهده نمونه")}
              </a>
              {/* <Button
                title="مشاهده نمونه"
                backgroundColor={isDark ? "bg-transparent" : "bg-white"}
                border={{
                  color: isDark ? "#ffffff55" : "rgba(192,57,25,0.24)",
                  width: "1px",
                }}
                width="24%"
                radius={false}
                twPaddings="py-4 px-6"
                color={isDark ? "text-white" : "font-bold text-red19"}
                onClick={() => {}}
                disabled={true}
              /> */}
            </div>
          </div>
          <div className="flex py-4">
            <Link
              to={"/videos/" + book?.id}
              className="bg-blueC0 text-green7B bg-opacity-5 font-semibold text-tiny rounded-md border border-solid border-blueC0 w-2/3 py-4 text-center flex flex-row items-center justify-center"
            >
              {window.t("مشاهده دوره ویدیویی این محصول")}
              <img
                src={arrow}
                alt=""
                className="mr-2 transform rotate-90 w-5"
              />
            </Link>
          </div>
        </div>
        <div className="flex flex-col w-1/3 ">
          <ProductStatusCard
            price={book?.product[type]?.price}
            garanty={book?.product[type]?.garantyText}
            suggestedCounter={book?.product[type]?.suggestedCounter}
            seller={book?.product[type]?.seller}
            offerPrice={book?.product[type]?.offerPrice}
            id={book?.product[type]?.id}
            shippingTime={book?.product[type]?.shippingTime}
            loading={loading}
          />
        </div>
      </header>
      {book?.product[type]?.properties?.length > 0 && (
        <ProductTab
          tabs={[
            {
              title: window.t("مشخصات"),
              components: (
                <Table specifications={book?.product[type]?.properties} />
              ),
            },
            {
              title: window.t("نقد و بررسی"),
              components: (
                <div className="bg-gray-100 rounded-md mt-4 w-full flex justify-center items-center h-40 text-green4F text-tiny">
                  {window.t("این بخش فعلا قابل دسترسی نیست.")}
                </div>
              ),
            },
            {
              title: window.t("پرسش و پاسخ"),
              components: (
                <div className="bg-gray-100 rounded-md mt-4 w-full flex justify-center items-center h-40 text-green4F text-tiny">
                  {window.t(" این بخش فعلا قابل دسترسی نیست.")}
                </div>
              ),
            },
          ]}
        />
      )}
    </div>
  );
};

const mapStateToProps = (state) => ({
  book: state.book.info,
  grades: state.publicApi.grades,
  isDark: state.publicApi.isDark,
  userId: state.user.status.id,
  loading: state.userProduct.loading,
});

const mapDispatchToProps = {
  getInfo: book.info,
  pushToCart: userProduct.add,
  setHeaderOptions: publicApi.setHeaderOptions,
};

export default connect(mapStateToProps, mapDispatchToProps)(ProductOverAll);
