import React, { useEffect, useState } from "react";
import axios from "axios";

import { connect } from "react-redux";
import { Link } from "react-router-dom";
import { ScrollingCarousel, Carousel } from "@trendyol-js/react-carousel";

import Product from "../../../../components/Product";
import VodProduct from "../../../../components/VodProduct";
import Loading from "../../../../components/Loading";
import { book, publicApi } from "../../../../redux/actions";
import moment from "jalali-moment";

import dropdownIcon from "../../../../assets/icons/dropdown-blue.svg";
import Posts from "./Posts";
import Pagination from "./Pagination";
const num = 6;

export const Main = ({
  books,
  grades,
  sortMethods,
  filterOptions,
  setFilterOptions,
  isMobile,
}) => {
  const [filterLoading, setFilterLoading] = useState(false);
  const [page, setPage] = useState(1);
  console.log(page);
  const [total, setTotal] = useState(books.length);

  useEffect(() => {
    // setFilterLoading(() => true);
    // setTimeout(() => {
    //   setFilterLoading(() => false);
    // }, 500);
    setPage(1);
  }, [filterOptions]);

  useEffect(() => {
    window.scrollTo(0, 0);
  }, []);

  useEffect(() => {
    setTotal(books.length);
  }, [books]);

  const Items = (type) => {
    const { grade, subject, available, sort, productType } = filterOptions;
    let byGradeFilter;
    let bySubjectFilter;
    let byAvailableFilter;
    let bySortFilter;
    if (grade) {
      byGradeFilter = books?.filter((book) => grades[book?.gradeId] === grade);
    } else {
      byGradeFilter = books;
    }
    if (subject) {
      bySubjectFilter = byGradeFilter?.filter(
        (book) =>
          book?.product[type]?.name?.indexOf(subject) !== -1 ||
          book?.name.indexOf(subject) !== -1
      );
    } else {
      bySubjectFilter = byGradeFilter;
    }
    if (available) {
      byAvailableFilter = bySubjectFilter?.filter(
        (book) => book.product[type].price
      );
    } else {
      byAvailableFilter = bySubjectFilter;
    }
    if (sort) {
      if (sort === window.t("ارزان ترین")) {
        bySortFilter = byAvailableFilter?.sort(
          (a, b) => a.product[type].price - b.product[type].price
        );
      } else if (sort === window.t("محبوب ترین")) {
        bySortFilter = byAvailableFilter?.sort(
          (a, b) => a.product[type].rate - b.product[type].rate
        );
      } else if (sort === window.t("جدیدترین")) {
        bySortFilter = byAvailableFilter?.sort(
          (a, b) => moment(a.createdAt) - moment(b.createdAt)
        );
      } else {
        bySortFilter = byAvailableFilter;
      }
    } else {
      bySortFilter = byAvailableFilter;
    }
    console.log("render here !");
    return bySortFilter;
    // setTotal(bySortFilter.length);
  };

  const elements = Items(1);
  const vods = Items(2);
  console.log(elements.length);

  const lastPage = Math.floor((elements.length - 1) / num) + 1;
  const pages = lastPage > 1 ? [...Array(lastPage)].map((e, i) => i + 1) : [];

  return (
    <div
      className="flex flex-col w-3/4 pb-20 min-h-screen"
      style={{ minWidth: "calc(100% * 3 / 4)" }}
    >
      <div className="flex w-full bg-blue rounded-lg border border-solid border-gray-200 p-2 items-center my-1.5 justify-center text-blue52">
        <div className="flex text-sm items-center mr-2 ml-4">
          <svg
            xmlns="http://www.w3.org/2000/svg"
            width="24"
            height="24"
            viewBox="0 0 24 24"
          >
            <g
              id="vuesax_linear_filter-tick"
              data-name="vuesax/linear/filter-tick"
              transform="translate(-620 -700)"
            >
              <g id="filter-tick">
                <path
                  id="Vector"
                  d="M9.5,4.75A4.678,4.678,0,0,1,8.82,7.2,4.735,4.735,0,0,1,4.75,9.5a4.62,4.62,0,0,1-2.56-.77A4.481,4.481,0,0,1,.69,7.2,4.686,4.686,0,0,1,0,4.75,4.754,4.754,0,0,1,4.75,0,4.421,4.421,0,0,1,5.79.12,4.74,4.74,0,0,1,9.5,4.75Z"
                  transform="translate(632.13 710)"
                  fill="none"
                  stroke="rgba(6, 186, 206"
                  strokeLinecap="round"
                  strokeLinejoin="round"
                  strokeWidth="1.5"
                />
                <path
                  id="Vector-2"
                  data-name="Vector"
                  d="M0,1.17,1.17,2.34,3.7,0"
                  transform="translate(635.03 713.58)"
                  fill="none"
                  stroke="rgba(6, 186, 206"
                  strokeLinecap="round"
                  strokeLinejoin="round"
                  strokeWidth="1.5"
                />
                <path
                  id="Vector-3"
                  data-name="Vector"
                  d="M0,0H24V24H0Z"
                  transform="translate(644 724) rotate(180)"
                  fill="none"
                  opacity="0"
                />
                <g id="Group">
                  <path
                    id="Vector-4"
                    data-name="Vector"
                    d="M17.38,2.02V4.24a3.825,3.825,0,0,1-1.01,2.33L14.61,8.12A4.421,4.421,0,0,0,13.57,8a4.754,4.754,0,0,0-4.75,4.75,4.686,4.686,0,0,0,.69,2.45,4.481,4.481,0,0,0,1.5,1.53v.34a2.23,2.23,0,0,1-.91,1.72l-1.41.91a2.058,2.058,0,0,1-3.13-1.72V12.63a3.91,3.91,0,0,0-.81-2.12L.91,6.47A3.407,3.407,0,0,1,0,4.45V2.12A2.051,2.051,0,0,1,2.02,0H15.36A2.027,2.027,0,0,1,17.38,2.02Z"
                    transform="translate(623.31 702)"
                    fill="none"
                    stroke="rgba(6, 186, 206"
                    strokeLinecap="round"
                    strokeLinejoin="round"
                    strokeWidth="1.5"
                  />
                </g>
              </g>
            </g>
          </svg>
          <span className="text-tiny text-greenBA font-bold">
            {window.t("مرتب سازی") + "" + ":"}
          </span>
        </div>
        <ul className="flex py-0 flex-1 gap-4">
          {sortMethods?.map((item, index) => (
            <li
              key={index}
              className={`text-sm rounded text-black py-2 px-3 transition-all font-semibold	duration-300 cursor-pointer ${
                filterOptions.sort === item ? "bg-greenBA text-white" : ""
              }`}
              onClick={() =>
                filterOptions.sort !== item
                  ? setFilterOptions({ ...filterOptions, sort: item })
                  : setFilterOptions({ ...filterOptions, sort: null })
              }
            >
              {item}
            </li>
          ))}
        </ul>
      </div>

      <div className="flex flex-col w-full relative">
        {filterLoading && (
          <div
            className="w-full flex justify-center items-center bg-white bg-opacity-70 z-20 backdrop-filter backdrop-blur-xl absolute left-0 top-0"
            style={{ height: "calc(100vh - 180px)" }}
          >
            <Loading size={4} color="bg-green-400" />
          </div>
        )}

        {books.length > 0 && (
          <div className="relative w-full mt-7 " style={{ direction: "ltr" }}>
            <Carousel
              show={Math.round(window.innerWidth / 666)}
              slide={2}
              swiping={true}
              useArrowKeys={true}
              transition={0.5}
              rightArrow={
                <img
                  className="bg-gray-50 p-2 absolute top-0 transform -rotate-90 -translate-y-5 translate-x-12  left-6 cursor-pointer"
                  src={dropdownIcon}
                  style={{
                    borderRight: "solid 2px #E5E7EB",
                    borderLeft: "solid 2px #E5E7EB",
                    borderBottom: "solid 2px #E5E7EB",
                    borderRadius: "4px",
                  }}
                  alt=""
                />
              }
              leftArrow={
                <img
                  className="bg-gray-50 p-2 absolute top-0 transform rotate-90 -translate-y-5 translate-x-12 left-0 cursor-pointer"
                  src={dropdownIcon}
                  style={{
                    borderRight: "solid 2px #E5E7EB",
                    borderLeft: "solid 2px #E5E7EB",
                    borderBottom: "solid 2px #E5E7EB",
                    borderRadius: "4px",
                  }}
                  alt=""
                />
              }
            >
              {vods.map((item, index) => (
                <VodProduct
                  video={item}
                  key={index}
                  index={index}
                  height={"calc(100vh / 5)"}
                  grades={grades}
                />
              ))}
            </Carousel>
          </div>
        )}

        <div className="w-full flex flex-row  flex-wrap  mt-0 border-t-2 border-solid border-gray-100 overflow-y-hidden gap-4 justify-evenly pt-3">
          {elements
            ?.slice((page - 1) * num, page * num)
            .map((product, index) => (
              <Product
                key={index}
                product={product}
                index={Number(index)}
                grades={grades}
                imageSize={4.5}
                type={0}
              />
            ))}

          {/* pagination */}
          <div className="w-full flex justify-center gap-x-2">
            {pages.map((e) => (
              <div
                className={`w-8 p-2 text-sm text-center rounded-md text-green7B cursor-pointer transform translate ${
                  page === true ? "bg-red-400" : "bg-blue-600"
                }`}
                onClick={() => setPage(e)}
              >
                {e}
              </div>
            ))}
          </div>
        </div>
      </div>
    </div>
  );
};

Main.defaultProps = {
  videos: [],
};

const mapStateToProps = (state) => ({
  isDark: state.publicApi.isDark,
  isMobile: state.publicApi.isMobile,
  sortMethods: state.book.sortFilters,
  filterOptions: state.book.filterOptions,
});

const mapDispatchToProps = {
  getList: book.list,
  setHeaderOptions: publicApi.setHeaderOptions,
  setFilterOptions: book.setFilterOptions,
};

export default connect(mapStateToProps, mapDispatchToProps)(Main);
