import React, { useState, useMemo } from "react";
import { connect } from "react-redux";
import { book } from "../../../../redux/actions";
import Checkbox from "../../../../components/Checkbox";
import Switch from "../../../../components/Switch";

//assets
import dropdownIcon from "../../../../assets/icons/dropdown-blue.svg";

export const Sidebar = ({
  levels,
  subjects,
  productTypes,
  setFilterOptions,
  filterOptions,
}) => {
  const [toggleList, setToggleList] = useState({
    subject: false,
    grade: false,
    productType: false,
  });

  const dropdownActionMap = {
    subject: () =>
      setToggleList({
        subject: !toggleList.subject,
        grade: false,
        productType: false,
      }),
    grade: () =>
      setToggleList({
        grade: !toggleList.grade,
        subject: false,
        productType: false,
      }),
    productType: () =>
      setToggleList({
        productType: !toggleList.productType,
        grade: false,
        subject: false,
      }),
  };

  const Dropdown = ({ list, title, name, active }) => {
    return (
      <div className="flex flex-col">
        <div
          className="flex flex-row justify-between items-center py-5 cursor-pointer"
          onClick={() => dropdownActionMap[name]()}
        >
          <strong className="font-semibold text-tiny text-green4F">
            {title}
          </strong>
          <img
            src={dropdownIcon}
            alt=""
            className={`w-4 transform transition-all ${
              toggleList[name] ? "rotate-180" : ""
            }`}
          />
        </div>
        <ul
          className={`list-none p-0 mt-2 mb-0 mx-0 flex overflow-x-hidden flex-col transition-all`}
          style={{
            maxHeight: !toggleList[name] ? 0 : "calc(100vh / 2.2)",
            overflowY: !toggleList[name] ? "hidden" : "scroll",
          }}
        >
          {list.map((item, index) => (
            <li
              key={index}
              className="flex flex-row items-center mb-3"
              onClick={() =>
                active !== item
                  ? setFilterOptions({ ...filterOptions, [name]: item })
                  : setFilterOptions({ ...filterOptions, [name]: null })
              }
            >
              <Checkbox checked={active === item} />
              <span className="text-tiny font-medium">{item}</span>
            </li>
          ))}
        </ul>
      </div>
    );
  };

  const CkeckItem = ({ title, name }) => {
    return (
      <div
        className="flex flex-row justify-between items-center py-4"
        onClick={() =>
          setFilterOptions({
            ...filterOptions,
            [name]: !filterOptions.available,
          })
        }
      >
        <span className="font-semibold text-tiny text-green4F">{title}</span>
        <Switch checked={filterOptions.available} />
      </div>
    );
  };

  const filterLength =
    (Object.values(filterOptions)[0] ? 1 : 0) +
    (Object.values(filterOptions)[1] ? 1 : 0) +
    (Object.values(filterOptions)[2] ? 1 : 0) +
    (Object.values(filterOptions)[3] ? 1 : 0);

  return (
    <div
      className="flex flex-col w-1/4 px-4 pt-5 pb-2 bg-gray-50 transform translate-y-5 border border-solid border-gray-200 rounded-md"
      style={{
        height: "fit-content",
      }}
    >
      <div className="flex justify-between items-center mb-10">
        <strong className="text-lg text-green4F">{window.t("فیلترها")}</strong>
        {filterLength > 0 && (
          <span
            className="text-tiny text-greenBA bg-greenBA bg-opacity-20 rounded-full px-3 py-2"
            onClick={() =>
              setFilterOptions({
                available: false,
                subject: null,
                grade: null,
                productType: null,
                sort: null,
              })
            }
          >
            {filterLength + " " + window.t("فیلتر")}
          </span>
        )}
      </div>
      <div className="flex flex-col divide-y divide-solid divide-gray-200">
        <Dropdown
          list={productTypes}
          title={window.t("نوع محصول")}
          name="productType"
          active={filterOptions.productType}
        />
        <Dropdown
          list={Object.values(levels)}
          title={window.t("پایه تحصیلی")}
          name="grade"
          active={filterOptions.grade}
        />
        <Dropdown
          list={subjects}
          title={window.t("عنوان کتاب")}
          name="subject"
          active={filterOptions.subject}
        />
        <CkeckItem title={window.t("فقط کالاهای موجود")} name={"available"} />
      </div>
    </div>
  );
};

const mapStateToProps = (state) => ({
  levels: state.book.levels,
  subjects: state.book.subjects,
  productTypes: state.book.productTypes,
  filterOptions: state.book.filterOptions,
});

const mapDispatchToProps = {
  setFilterOptions: book.setFilterOptions,
};

export default connect(mapStateToProps, mapDispatchToProps)(Sidebar);
