import React from "react";
import { connect } from "react-redux";
import { book } from "../../../../redux/actions";
import _ from "lodash";

import Search from "../../../../components/Search";
import Select from "../../../../components/Select";

import searchLight from "../../../../assets/icons/search-light.svg";

export const Header = ({
  setFilterOptions,
  filterOptions,
  levels,
  productTypes,
  isDark,
}) => {
  return (
    <header
      className="w-full px-4 fixed top-0 left-0  pb-5 z-10"
      style={{ backgroundColor: isDark ? "#061B30" : "white" }}
    >
      <Search
        backgroundColor="bg-gray-100"
        borderColor="border-grayDB dark:border-gray45"
        textColor="text-black dark:text-gray70"
        icon={searchLight}
        onChange={_.debounce(
          (val) => setFilterOptions({ ...filterOptions, search: val }),
          700
        )}
      />
      <div className="w-full flex flex-row justify-between mt-3">
        <Select
          margin="ml-1"
          fill="fill-green-700 dark:fill-white"
          borderColor="border-grayDB dark:border-gray45"
          backgroundColor="bg-gray-100"
          onChange={(name, value) =>
            value === window.t("نوع محصول")
              ? setFilterOptions({ ...filterOptions, [name]: null })
              : setFilterOptions({ ...filterOptions, [name]: value })
          }
          name="productType"
          options={productTypes}
        />
        <Select
          margin="mr-1"
          fill="fill-green-700 dark:fill-white"
          borderColor="border-grayDB dark:border-gray45"
          backgroundColor="bg-gray-100"
          onChange={(name, value) =>
            value === window.t("پایه تحصیلی")
              ? setFilterOptions({ ...filterOptions, [name]: null })
              : setFilterOptions({ ...filterOptions, [name]: value })
          }
          name="grade"
          options={Object.values(levels)}
        />
      </div>
    </header>
  );
};

const mapStateToProps = (state) => ({
  levels: state.publicApi.grades,
  productTypes: state.book.productTypes,
  filterOptions: state.book.filterOptions,
  isDark: state.publicApi.isDark,
});

const mapDispatchToProps = {
  setFilterOptions: book.setFilterOptions,
};

export default connect(mapStateToProps, mapDispatchToProps)(Header);
