import React, { useEffect, useState } from "react";
import { connect } from "react-redux";
import { Link } from "react-router-dom";

import Loading from "../../../../components/Loading";

//assets
import whitePlayIcon from "../../../../components/VodProduct/white-play-button-icon.svg";

export const Main = ({ books, filterOptions, grades }) => {
  const [filterLoading, setFilterLoading] = useState(false);

  useEffect(() => {
    setFilterLoading(() => true);
    setTimeout(() => {
      setFilterLoading(() => false);
    }, 500);
  }, [filterOptions]);

  const Items = (type) => {
    const { grade, subject, available, sort, productType, search } =
      filterOptions;
    let byGradeFilter;
    let bySubjectFilter;
    let byAvailableFilter;
    let bySearchFilter;
    if (grade) {
      byGradeFilter = books?.filter((book) => grades[book?.gradeId] === grade);
    } else {
      byGradeFilter = books;
    }
    if (subject) {
      bySubjectFilter = byGradeFilter?.filter(
        (book) =>
          book?.product[type]?.name?.indexOf(subject) !== -1 ||
          book?.name.indexOf(subject) !== -1
      );
    } else {
      bySubjectFilter = byGradeFilter;
    }
    if (available) {
      byAvailableFilter = bySubjectFilter?.filter(
        (book) => book.product[type].price
      );
    } else {
      byAvailableFilter = bySubjectFilter;
    }
    if (search) {
      bySearchFilter = byAvailableFilter?.filter(
        (book) =>
          book?.product[type]?.name?.indexOf(search) !== -1 ||
          book?.name.indexOf(search) !== -1
      );
    } else {
      bySearchFilter = byAvailableFilter;
    }

    return filterOptions.productType === window.t("دوره ویدئویی")
      ? bySearchFilter?.map((product, index) => (
          <Link
            to={"/videos/" + product?.id}
            className={`w-full flex flex-col p-3 mb-5 shadow-md mx-4`}
            key={index}
          >
            <div
              className="relative w-full mb-3"
              style={{ height: "calc(100vh / 5)" }}
            >
              <img
                src={"https://dnvn.ir/api/v1/file/" + product?.fileIds}
                className="w-full rounded-md h-full"
              />
              <div
                className={`absolute left-1/2 top-1/2 rounded-full p-4 group-hover:scale-125 transform -translate-x-1/2 -translate-y-1/2 duration-300 bg-playButtonIcon bg-black bg-opacity-20 backdrop-filter backdrop-blur-md`}
              >
                <img src={whitePlayIcon} alt="" className="w-5 h-5" />
              </div>
            </div>

            <strong className="text-blue5F dark:text-white text-tiny lg:text-tiny font-bold mb-2">
              {product?.name}
            </strong>
            <span className="text-tiny lg:text-sm text-green7B dark:text-greenBA font-light mb-4">
              {window.t("پایه") + " " + grades[product?.gradeId]}
            </span>
            <div className="w-full flex flex-row justify-center font-bold lg:font-medium text-lg lg:text-tiny text-blue5F dark:text-white">
              {product?.product[2]?.price + " " + window.t("تومان")}
            </div>
          </Link>
        ))
      : bySearchFilter?.map((product) => (
          <>
            {(productType
              ? productType === window.t("کتاب دیجیتال")
              : true) && (
              <Link
                key={product?.product[0]?.id}
                to={"/products/" + product?.id}
                className={`w-1/2 flex flex-col p-3`}
              >
                <img
                  src={"https://dnvn.ir/api/v1/file/" + product?.fileIds}
                  className="w-full rounded-md mb-3 object-contain"
                />
                <strong className="text-blue5F dark:text-white text-tiny font-bold lg:text-sm lg:font-medium mb-2">
                  {window.t("کتاب دیجیتال") + " " + product?.name}
                </strong>
                <span className="text-tiny lg:text-xs text-green7B dark:text-greenBA font-light mb-4">
                  {window.t("پایه") + " " + grades[product?.gradeId]}
                </span>
                <div className="w-full flex flex-row justify-center font-bold lg:font-medium text-lg lg:text-sm text-blue5F dark:text-white">
                  {product?.product[0]?.price + " " + window.t("تومان")}
                </div>
              </Link>
            )}
            {(productType ? productType === window.t("کتاب فیزیکی") : true) && (
              <Link
                key={product?.product[1]?.id}
                to={"/products/" + product?.id}
                className={`w-1/2 flex flex-col p-3`}
              >
                <img
                  src={"https://dnvn.ir/api/v1/file/" + product?.fileIds}
                  className="w-full rounded-md mb-3"
                  alt=""
                />
                <strong className="text-blue5F dark:text-white text-tiny font-bold lg:text-sm lg:font-medium mb-2">
                  {window.t("کتاب فیزیکی") + " " + product?.name}
                </strong>
                <span className="text-tiny lg:text-xs text-green7B dark:text-greenBA font-light mb-4">
                  {window.t("پایه") + " " + grades[product?.gradeId]}
                </span>
                <div className="w-full flex flex-row justify-center font-bold lg:font-medium text-lg lg:text-sm text-blue5F dark:text-white">
                  {product?.product[1]?.price + " " + window.t("تومان")}
                </div>
              </Link>
            )}
          </>
        ));
  };

  return (
    <div className="h-full overflow-y-scroll w-full flex flex-wrap py-32">
      {filterOptions?.productType === window.t("دوره ویدئویی") && Items(2)}
      {filterOptions?.productType === window.t("کتاب دیجیتال") && Items(0)}
      {filterOptions?.productType === window.t("کتاب فیزیکی") && Items(1)}
      {!filterOptions?.productType && Items(0)}
      {filterLoading && (
        <div className="w-full h-screen flex justify-center items-center bg-white bg-opacity-20 backdrop-filter backdrop-blur-xl fixed left-0 top-0">
          <Loading size={4} color="bg-green-400" />
        </div>
      )}
    </div>
  );
};

const mapStateToProps = (state) => ({
  filterOptions: state.book.filterOptions,
});

const mapDispatchToProps = {};

export default connect(mapStateToProps, mapDispatchToProps)(Main);
