import React, { useState } from "react";

import Voice from "./Voice";
import Video from "./Video";
import PPT from "./PPT";
import PDF from "./PDF";
import Links from "./Links";

//assets

export default function Tab({ data }) {
  const [dataType, setDataType] = useState("all");
  return (
    <div className="w-full flex flex-col rounded-md overflow-hidden mt-5 border border-solid border-blueFF1 dark:border-opacity-10">
      <div className="w-full flex flex-row justify-between">
        <button
          onClick={() => setDataType("all")}
          className={`py-2 w-1/6 border-b border-solid text-blueC0 text-sm dark:bg-opacity-10 dark:text-white border-blueFF1 dark:border-opacity-10 ${
            dataType === "all"
              ? "bg-blueFF1 font-medium"
              : "bg-white font-normal"
          }`}
        >
          {window.t("تمامی محتوا")}
        </button>
        <button
          onClick={() => setDataType("voice")}
          className={`py-2 w-1/6 border-b border-solid text-blueC0 text-sm dark:bg-opacity-10 dark:text-white border-blueFF1 dark:border-opacity-10 ${
            dataType === "voice"
              ? "bg-blueFF1 font-medium"
              : "bg-white font-normal"
          }`}
        >
          {window.t("صوت")}
        </button>
        <button
          onClick={() => setDataType("video")}
          className={`py-2 w-1/6 border-b border-solid text-blueC0 text-sm dark:bg-opacity-10 dark:text-white border-blueFF1 dark:border-opacity-10 ${
            dataType === "video"
              ? "bg-blueFF1 font-medium"
              : "bg-white font-normal"
          }`}
        >
          {window.t("ویدئو")}
        </button>
        <button
          onClick={() => setDataType("pdf")}
          className={`py-2 w-1/6 border-b border-solid text-blueC0 text-sm dark:bg-opacity-10 dark:text-white border-blueFF1 dark:border-opacity-10 ${
            dataType === "pdf"
              ? "bg-blueFF1 font-medium"
              : "bg-white font-normal"
          }`}
        >
          {window.t("پی دی اف")}
        </button>
        <button
          onClick={() => setDataType("ppt")}
          className={`py-2 w-1/6 border-b border-solid text-blueC0 text-sm dark:bg-opacity-10 dark:text-white border-blueFF1 dark:border-opacity-10 ${
            dataType === "ppt"
              ? "bg-blueFF1 font-medium"
              : "bg-white font-normal"
          }`}
        >
          {window.t("پاور پوینت")}
        </button>
        <button
          onClick={() => setDataType("links")}
          className={`py-2 w-1/6 border-b border-solid text-blueC0 text-sm dark:bg-opacity-10 dark:text-white border-blueFF1 dark:border-opacity-10 ${
            dataType === "links"
              ? "bg-blueFF1 font-medium"
              : "bg-white font-normal"
          }`}
        >
          {window.t("لینک ها")}
        </button>
      </div>
      <div className="flex flex-col w-full p-4">
        {dataType === "all" && (
          <>
            {data.voice && <Voice data={data?.voice} />}
            {data.video && <Video data={data?.video} />}
            {data.ppt && <PPT data={data.ppt} />}
            {data.pdf && <PDF data={data.pdf} />}
            {data.links && <Links data={data.links} />}
          </>
        )}
        {dataType === "voice" && (
          <>
            {data.voice ? (
              <Voice data={data.voice} />
            ) : (
              <p className="text-sm text-gray70">
                {window.t("فایل صدا یافت نشد.")}
              </p>
            )}
          </>
        )}
        {dataType === "video" && (
          <>
            {data.video ? (
              <Video data={data.video} />
            ) : (
              <p className="text-sm text-gray70">
                {window.t("فایل تصویری یافت نشد.")}
              </p>
            )}
          </>
        )}
        {dataType === "ppt" && (
          <>
            {data.ppt ? (
              <PPT data={data.ppt} />
            ) : (
              <p className="text-sm text-gray70">
                {window.t("فایل پاورپوینت یافت نشد.")}
              </p>
            )}
          </>
        )}
        {dataType === "pdf" && (
          <>
            {data.pdf ? (
              <PDF data={data.pdf} />
            ) : (
              <p className="text-sm text-gray70">
                {window.t("فایل پی دی اف یافت نشد.")}
              </p>
            )}
          </>
        )}
        {dataType === "links" && (
          <>
            {data.links ? (
              <Links data={data.links} />
            ) : (
              <p className="text-sm text-gray70">
                {window.t("لینکی پیدا نشد.")}
              </p>
            )}
          </>
        )}
      </div>
    </div>
  );
}
