import React, { useEffect } from "react";
import { connect } from "react-redux";
import { publicApi, qr } from "../../../redux/actions";
import Tab from "./components/Tab";

export const Content = ({
  headerOptions,
  setHeaderOptions,
  data,
  getQrData,
  grades,
}) => {
  useEffect(() => {
    const path = window.location.pathname;
    setHeaderOptions(headerOptions);
    getQrData({ tail: path.slice(path.lastIndexOf("/") + 1, path.length) });
  }, []);

  useEffect(() => {
    if (data) {
    }
  }, [data]);

  return (
    <div className="flex-1 flex flex-col px-4 pb-20">
      <div className="flex w-full flex-row">
        <img
          className="rounded-md"
          src={`https://dnvn.ir/api/v1/file/${data?.book?.fileIds}`}
          style={{ width: 80, height: 120 }}
        />
        <div className="flex flex-col mr-3 pt-2">
          <strong className="text-base text-blue5F dark:text-white">
            {data?.book?.name}
          </strong>
          <span className="text-sm text-blueC0 mt-2 dark:text-greenBA">
            {grades[data?.book?.gradeId]}
          </span>
          <p className="text-sm mt-2 text-blueC0 dark:text-greenBA">{`${window.t(
            "شما در حال مشاهده صفحه"
          )} ${data?.qr?.pageNumber} ${window.t("هستید.")}`}</p>
        </div>
      </div>

      <Tab
        data={{
          voice: data?.qr?.content?.filter((obj) => obj.type === "voice")[0],
          video: data?.qr?.content?.filter((obj) => obj.type === "video")[0],
          pdf: data?.qr?.content?.filter((obj) => obj.type === "pdf")[0],
          ppt: data?.qr?.content?.filter((obj) => obj.type === "ppt")[0],
          links: data?.qr?.content?.filter((obj) => obj.type === "links")[0],
        }}
      />
    </div>
  );
};

const mapStateToProps = (state) => ({
  data: state.qr.list,
  grades: state.publicApi.grades,
});

const mapDispatchToProps = {
  setHeaderOptions: publicApi.setHeaderOptions,
  getQrData: qr.info,
};

export default connect(mapStateToProps, mapDispatchToProps)(Content);

Content.defaultProps = {
  data: {
    name: window.t("ریاضیات گسسته خیلی پیشرفته"),
    grade: window.t("پایه هفتم ابتدایی"),
    page: "67",
    percent: "62",
    voice: {
      name: window.t("استاد رضایی: فصل پنجم توضیح در مورد آتش فشان ها"),
      file: 1,
    },
    video: { name: window.t("ویدئوی آزمایش آتشفشان سرکه ای"), file: 1 },
    pdf: { name: window.t("فایل پی دی اف ارائه درس آتشفشان ها"), file: 1 },
    ppt: { name: window.t("فایل پاورپوینت ارائه درس آتشفشان ها"), file: 1 },
    links: [
      window.t("وبسایت آموزشی دانوین"),
      window.t("وبسایت رسمی مدیریت راهبردی کشور"),
      window.t("سازمان تبلیغات صنایع سبک "),
    ],
  },
};
