import React, { useState, useEffect } from "react";
import { connect } from "react-redux";
import { userProduct } from "../../../redux/actions";
import separate from "../../../utils/separate";
import Loading from "../../../components/Loading";

// assets
import bookImage from "../../../assets/images/zist-11.svg";
import exitIcon from "../../../assets/icons/exit.svg";
import deleteIcon from "../../../assets/icons/delete.svg";

function Product({ product, grades, pushToCart, isMobile, loading }) {
  return isMobile ? (
    <div className="flex flex-row justify-between py-5 border-b border-solid border-grayDB dark:border-gray45">
      <div className="flex flex-row ">
        <img
          src={"https://dnvn.ir/api/v1/file/" + product.product.book.fileIds}
          className="rounded-md w-20"
        />
        <div className="flex flex-col pr-2">
          <strong className="text-base text-green4F mb-3 dark:text-white">
            {product.product.book.name}
          </strong>
          <span className="text-gray70 text-tiny mb-2 dark:text-greenBA">
            {window.t("پایه") + " " + grades[product.product.book.gradeId]}
          </span>
          <span className="text-gray70 text-tiny dark:text-greenBA">
            {product.productType === 2
              ? window.t("نسخه فیزیکی")
              : window.t("نسخه دیجیتال")}
          </span>
        </div>
      </div>
      <div className="flex flex-col justify-between items-end ">
        <img
          src={exitIcon}
          className="w-4"
          alt=""
          onClick={() =>
            pushToCart(
              {
                productId: product?.productId,
                userId: product?.userId,
                count: product?.productType === 1 ? -1 : -product?.count,
              },
              {},
              { id: product?.factorId }
            )
          }
        />
        <div className="flex flex-col items-center">
          {product.productType === 2 && (
            <div className="flex flex-row items-center mb-3">
              <button
                className="rounded-md pt-2 pb-1.5 px-3 border border-solid border-blueC0 text-blueC0"
                onClick={() =>
                  pushToCart({
                    productId: product?.productId,
                    userId: product?.userId,
                    count: 1,
                  })
                }
              >
                +
              </button>
              <span className="mx-2.5 font-semibold text-4xl text-blueC0">
                {loading ? (
                  <Loading size={2} color="bg-green-500" />
                ) : (
                  product.count
                )}
              </span>
              {
                <>
                  {product.count === 1 ? (
                    <img
                      onClick={() =>
                        pushToCart(
                          {
                            productId: product?.productId,
                            userId: product?.userId,
                            count:
                              product?.productType === 1 ? -1 : -product?.count,
                          },
                          {},
                          { id: product?.factorId }
                        )
                      }
                      src={deleteIcon}
                      alt="delete"
                      className="border border-blue-800 border-solid p-1 w-8 bg-red-100 rounded-md cursor-pointer"
                    />
                  ) : (
                    <button
                      className="rounded-md pt-2 pb-1.5 px-3 font-bold border border-solid border-blueC0 text-blueC0 dark:border-blueC0 dark:text-blueC0"
                      onClick={() =>
                        pushToCart({
                          productId: product?.productId,
                          userId: product?.userId,
                          count: -1,
                        })
                      }
                    >
                      -
                    </button>
                  )}
                </>
              }
            </div>
          )}
          <strong className="font-bold text-md text-blue5F dark:text-white">
            {separate(product.product.price * product.count)}&nbsp;
            {window.t("تومان")}
          </strong>
        </div>
      </div>
    </div>
  ) : (
    <div
      className="flex flex-row w-full gap-10 py-4 border-b border-solid border-gray-200"
      onClick={() => localStorage.setItem("cartItem", product?.id)}
    >
      <div className="w-3/4 flex flex-row">
        <img
          src={"https://dnvn.ir/api/v1/file/" + product?.product?.book?.fileIds}
          className="rounded-md w-20"
        />
        <div className="flex flex-col pr-4 pt-1">
          <strong className="text-lg text-blue5F mb-1 dark:text-white font-semibold">
            {product?.product?.book?.name}
          </strong>
          <div className="flex flex-row items-center mt-4">
            <span className="w-2 h-2 bg-greenBA rounded-md ml-1"></span>
            <div className="text-gray70 text-sm dark:text-greenBA">
              {window.t("پایه") + " " + grades[product?.product?.book?.gradeId]}
            </div>
            <span className="w-2 h-2 bg-greenBA rounded-md mr-5 ml-1"></span>
            <div className="text-gray70 text-sm dark:text-greenBA">
              {product?.productType === 2
                ? window.t("نسخه فیزیکی")
                : window.t("نسخه دیجیتال")}
            </div>
          </div>
          <div className="flex flex-row items-center pl-4 mt-6">
            <strong className="font-semibold text-xl text-blue5F dark:text-white">
              &nbsp;{separate(product?.product?.price * product.count)}
              &nbsp;&nbsp;
              {window.t("تومان")}
            </strong>
          </div>
        </div>
      </div>
      <div className="w-1/4 flex flex-row items-center">
        <button
          className="rounded-md pt-1 px-1.5 border border-solid border-blueC0 text-blueC0 text-lg font-bold"
          onClick={() =>
            pushToCart({
              productId: product?.productId,
              userId: product?.userId,
              count: 1,
            })
          }
        >
          +
        </button>
        <span className="mx-2.5 font-semibold text-5xl text-green4F w-8 flex justify-center">
          {loading ? <Loading size={2} color="bg-green-500" /> : product.count}
        </span>
        {
          <>
            {product.count === 1 ? (
              <img
                onClick={() =>
                  pushToCart(
                    {
                      productId: product?.productId,
                      userId: product?.userId,
                      count: product?.productType === 1 ? -1 : -product?.count,
                    },
                    {},
                    { id: product?.factorId }
                  )
                }
                src={deleteIcon}
                alt="delete"
                className="border border-red-300 border-solid p-1 w-7 bg-red-100 rounded-md cursor-pointer"
              />
            ) : (
              <button
                className="rounded-md px-2 font-bold border border-solid border-blueC0 text-blueC0 dark:border-blueC0 dark:text-blueC0 text-2xl"
                onClick={() =>
                  pushToCart({
                    productId: product?.productId,
                    userId: product?.userId,
                    count: -1,
                  })
                }
              >
                -
              </button>
            )}
          </>
        }
      </div>
    </div>
  );
}

const mapStateToProps = (state) => ({
  grades: state.publicApi.grades,
  isMobile: state.publicApi.isMobile,
});

const mapDispatchToProps = {
  pushToCart: userProduct.add,
};

export default connect(mapStateToProps, mapDispatchToProps)(Product);
